tokens = {
    '<pad>',
    '<capital>',
    '<upper>',
    '<nospace>',
    '!',
    '"',
    '#',
    '$',
    '%',
    '&',
    '\'',
    '(',
    ')',
    '*',
    '+',
    ',',
    '-',
    '.',
    '/',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    ':',
    ';',
    '<',
    '=',
    '>',
    '?',
    '@',
    '[',
    '\\',
    ']',
    '^',
    '_',
    'a',
    'abandoned',
    'abdominal',
    'abhorrent',
    'abiding',
    'ability',
    'abject',
    'able',
    'abnormal',
    'abounding',
    'abrasive',
    'abrupt',
    'absence',
    'absent',
    'absentminded',
    'absolute',
    'absorbed',
    'absorbing',
    'abstracted',
    'absurd',
    'abundant',
    'abuse',
    'abusive',
    'abysmal',
    'academic',
    'accept',
    'acceptable',
    'accepting',
    'access',
    'accessible',
    'accident',
    'accidental',
    'acclaimed',
    'accommodating',
    'accommodation',
    'accompanying',
    'account',
    'accountable',
    'accurate',
    'accusative',
    'accused',
    'accusing',
    'acerbic',
    'achievable',
    'aching',
    'acid',
    'acidic',
    'acknowledged',
    'acoustic',
    'acrid',
    'acrimonious',
    'acrobatic',
    'act',
    'acting',
    'action',
    'actionable',
    'active',
    'activity',
    'actual',
    'ad',
    'adamant',
    'adaptable',
    'adaptive',
    'addicted',
    'addictive',
    'addition',
    'additional',
    'address',
    'adept',
    'adequate',
    'adhesive',
    'adjacent',
    'adjoining',
    'adjustable',
    'adjusted',
    'administration',
    'administrative',
    'admirable',
    'admired',
    'admiring',
    'admit',
    'adopted',
    'adoptive',
    'adorable',
    'adored',
    'adoring',
    'adrenalized',
    'adroit',
    'adult',
    'advance',
    'advanced',
    'advantage',
    'advantageous',
    'adventurous',
    'adversarial',
    'advice',
    'advisable',
    'aerial',
    'affable',
    'affected',
    'affectionate',
    'affirmative',
    'affordable',
    'afraid',
    'after',
    'afternoon',
    'age',
    'ageless',
    'agency',
    'agent',
    'aggrandizing',
    'aggravated',
    'aggravating',
    'aggressive',
    'agitated',
    'agonizing',
    'agrarian',
    'agreeable',
    'agreement',
    'agriculture',
    'aid',
    'aim',
    'aimless',
    'air',
    'aircraft',
    'airline',
    'airsick',
    'ajar',
    'alan',
    'alarmed',
    'alarming',
    'alert',
    'algebraic',
    'alien',
    'alienated',
    'alike',
    'alive',
    'all',
    'alleged',
    'allowable',
    'alluring',
    'allusive',
    'ally',
    'alone',
    'aloof',
    'alterable',
    'alternating',
    'alternative',
    'amazed',
    'amazing',
    'ambiguous',
    'ambitious',
    'ambulant',
    'ambulatory',
    'amiable',
    'amicable',
    'amount',
    'amphibian',
    'amuse',
    'amused',
    'amusing',
    'analysis',
    'ancient',
    'and',
    'anecdotal',
    'anemic',
    'angelic',
    'angered',
    'angry',
    'angular',
    'animal',
    'animated',
    'annoyed',
    'annoying',
    'annual',
    'anonymous',
    'another',
    'answer',
    'antagonistic',
    'anticipated',
    'anticlimactic',
    'anticorrosive',
    'antiquated',
    'antiseptic',
    'antisocial',
    'antsy',
    'anxious',
    'apathetic',
    'apologetic',
    'apologizing',
    'appalling',
    'appeal',
    'appealing',
    'appearance',
    'appetizing',
    'applauding',
    'applicable',
    'application',
    'applicative',
    'appointment',
    'appreciative',
    'apprehensive',
    'approach',
    'approachable',
    'approaching',
    'appropriate',
    'approval',
    'approve',
    'approving',
    'approximate',
    'aquatic',
    'architectural',
    'ardent',
    'arduous',
    'area',
    'arguable',
    'argued',
    'argument',
    'argumentative',
    'arid',
    'aristocratic',
    'arm',
    'army',
    'aromatic',
    'around',
    'arresting',
    'arrival',
    'arrogant',
    'art',
    'artful',
    'article',
    'artificial',
    'artist',
    'artistic',
    'artless',
    'ascend',
    'ashamed',
    'ask',
    'asleep',
    'aspect',
    'aspiring',
    'assemble',
    'assembly',
    'assertive',
    'assessment',
    'assignable',
    'assistance',
    'association',
    'assorted',
    'assumable',
    'assured',
    'assuring',
    'astonished',
    'astonishing',
    'astounded',
    'astounding',
    'astringent',
    'astronomical',
    'astute',
    'asymmetrical',
    'athletic',
    'atmosphere',
    'atomic',
    'atrocious',
    'attachable',
    'attack',
    'attainable',
    'attempt',
    'attention',
    'attentive',
    'attitude',
    'attractive',
    'attributable',
    'atypical',
    'audacious',
    'audience',
    'auspicious',
    'authentic',
    'author',
    'authoritarian',
    'authoritative',
    'authority',
    'autobiographic',
    'autographed',
    'automatic',
    'autonomous',
    'autumn',
    'available',
    'avant',
    'avenging',
    'average',
    'avian',
    'avid',
    'avoidable',
    'awake',
    'awakening',
    'award',
    'aware',
    'awareness',
    'away',
    'awesome',
    'awful',
    'awkward',
    'axiomatic',
    'b',
    'babbling',
    'baby',
    'back',
    'background',
    'backhanded',
    'bacterial',
    'bad',
    'baffled',
    'baffling',
    'bag',
    'balance',
    'balanced',
    'bald',
    'balding',
    'ball',
    'balmy',
    'band',
    'bandaged',
    'banging',
    'bank',
    'bankable',
    'banned',
    'bantering',
    'bar',
    'barbaric',
    'barbarous',
    'barbequed',
    'barefooted',
    'barking',
    'barren',
    'base',
    'bashful',
    'basic',
    'basis',
    'bath',
    'battered',
    'battle',
    'batty',
    'bawling',
    'beach',
    'beady',
    'beaming',
    'bearable',
    'beautiful',
    'beauty',
    'beckoning',
    'bed',
    'bedazzled',
    'bedazzling',
    'bedroom',
    'beefy',
    'beeping',
    'befitting',
    'before',
    'befuddled',
    'begin',
    'beginning',
    'behalf',
    'behaved',
    'behaviour',
    'belching',
    'belief',
    'believable',
    'bellicose',
    'belligerent',
    'bellowing',
    'bendable',
    'bending',
    'beneficial',
    'benefit',
    'benevolent',
    'benign',
    'bent',
    'berserk',
    'best',
    'betrayed',
    'better',
    'bewildered',
    'bewildering',
    'bewitched',
    'bewitching',
    'biased',
    'biblical',
    'big',
    'bigger',
    'biggest',
    'bighearted',
    'bigoted',
    'bilingual',
    'bill',
    'billable',
    'billowy',
    'binary',
    'binding',
    'bioactive',
    'biodegradable',
    'biographical',
    'bird',
    'birth',
    'bishop',
    'bite',
    'biting',
    'bitter',
    'bitty',
    'bizarre',
    'black',
    'blamable',
    'blame',
    'blameless',
    'bland',
    'blank',
    'blaring',
    'blasphemous',
    'blatant',
    'blazing',
    'bleached',
    'bleak',
    'bleary',
    'bless',
    'blessed',
    'blind',
    'blindfolded',
    'blinding',
    'blissful',
    'blistering',
    'bloated',
    'block',
    'blonde',
    'blood',
    'blooded',
    'bloodied',
    'bloodthirsty',
    'bloody',
    'blooming',
    'blossoming',
    'blue',
    'blundering',
    'blunt',
    'blurred',
    'blurry',
    'blushing',
    'board',
    'boastful',
    'boat',
    'bob',
    'bodacious',
    'bodied',
    'body',
    'bohemian',
    'boiling',
    'boisterous',
    'bold',
    'book',
    'bookish',
    'booming',
    'boorish',
    'border',
    'bordering',
    'bore',
    'bored',
    'boring',
    'born',
    'borrow',
    'bossy',
    'both',
    'bothered',
    'bottle',
    'bottom',
    'bouncing',
    'bouncy',
    'boundless',
    'bountiful',
    'box',
    'boy',
    'boyish',
    'braided',
    'brain',
    'brainless',
    'brainy',
    'branch',
    'brash',
    'brassy',
    'brave',
    'brawny',
    'brazen',
    'bread',
    'break',
    'breakable',
    'breakfast',
    'breath',
    'breathable',
    'breathless',
    'breathtaking',
    'breezy',
    'bribable',
    'brick',
    'bridge',
    'brief',
    'bright',
    'brilliant',
    'briny',
    'brisk',
    'bristly',
    'broad',
    'broken',
    'bronchial',
    'bronze',
    'bronzed',
    'brooding',
    'brother',
    'brown',
    'bruised',
    'brunette',
    'brutal',
    'brutish',
    'bubbly',
    'budget',
    'build',
    'built',
    'bulky',
    'bumpy',
    'bungling',
    'buoyant',
    'bureaucratic',
    'burly',
    'burnable',
    'burning',
    'bus',
    'bush',
    'bushy',
    'busiest',
    'business',
    'bustling',
    'busy',
    'buy',
    'buzzing',
    'c',
    'cabinet',
    'cackling',
    'caged',
    'cagey',
    'calculable',
    'calculated',
    'calculating',
    'call',
    'callous',
    'calm',
    'calming',
    'calorie',
    'camouflaged',
    'campaign',
    'cancelled',
    'cancer',
    'cancerous',
    'candid',
    'candidate',
    'cantankerous',
    'capable',
    'capacity',
    'capital',
    'capricious',
    'captain',
    'captivated',
    'captivating',
    'captive',
    'car',
    'carb',
    'card',
    'care',
    'career',
    'carefree',
    'careful',
    'careless',
    'caring',
    'carnivorous',
    'carpeted',
    'carsick',
    'case',
    'cash',
    'castle',
    'casual',
    'cat',
    'catastrophic',
    'catatonic',
    'catch',
    'catchable',
    'cause',
    'caustic',
    'cautious',
    'cavalier',
    'cavernous',
    'ceaseless',
    'ceiling',
    'celebrated',
    'celestial',
    'cell',
    'centered',
    'central',
    'centre',
    'century',
    'cerebral',
    'ceremonial',
    'certain',
    'certifiable',
    'certified',
    'chain',
    'chair',
    'chairman',
    'challenge',
    'challenged',
    'challenging',
    'championship',
    'chance',
    'chancellor',
    'change',
    'changeable',
    'changing',
    'channel',
    'chanting',
    'chapter',
    'character',
    'charge',
    'charging',
    'charismatic',
    'charitable',
    'charity',
    'charmed',
    'charming',
    'chattering',
    'chatting',
    'chatty',
    'chauvinistic',
    'cheap',
    'cheapest',
    'cheeky',
    'cheerful',
    'cheering',
    'cheerless',
    'cheery',
    'chemical',
    'chest',
    'chewable',
    'chewy',
    'chic',
    'chicken',
    'chief',
    'child',
    'childish',
    'childlike',
    'chilling',
    'chilly',
    'china',
    'chivalrous',
    'choice',
    'choking',
    'choppy',
    'christ',
    'chronological',
    'chubby',
    'chuckling',
    'chunky',
    'church',
    'cinematic',
    'circling',
    'circular',
    'circumstantial',
    'city',
    'civil',
    'civilian',
    'civilized',
    'claim',
    'clammy',
    'clamoring',
    'clandestine',
    'clanging',
    'clapping',
    'clashing',
    'class',
    'classic',
    'classical',
    'classifiable',
    'classified',
    'classy',
    'clause',
    'clean',
    'cleanable',
    'clear',
    'cleared',
    'clearheaded',
    'clever',
    'client',
    'climatic',
    'climbable',
    'clinging',
    'clingy',
    'clinical',
    'cliquish',
    'clogged',
    'cloistered',
    'close',
    'closeable',
    'closed',
    'cloudless',
    'cloudy',
    'clownish',
    'club',
    'clueless',
    'clumsy',
    'cluttered',
    'co',
    'coachable',
    'coal',
    'coarse',
    'coast',
    'cockamamie',
    'cocky',
    'code',
    'codified',
    'coercive',
    'coffee',
    'cognitive',
    'coherent',
    'cohesive',
    'coincidental',
    'cold',
    'coldhearted',
    'collaborative',
    'collapsed',
    'collapsing',
    'collectable',
    'collection',
    'college',
    'collegial',
    'colloquial',
    'colonial',
    'colored',
    'colorful',
    'colorless',
    'colossal',
    'colour',
    'combative',
    'combination',
    'combined',
    'come',
    'comedy',
    'comfort',
    'comfortable',
    'comforted',
    'comforting',
    'comical',
    'command',
    'commanding',
    'commemorative',
    'commendable',
    'commercial',
    'commission',
    'commitment',
    'committed',
    'committee',
    'common',
    'communal',
    'communicable',
    'communication',
    'communicative',
    'communist',
    'community',
    'compact',
    'company',
    'comparable',
    'comparative',
    'comparison',
    'compassionate',
    'compelling',
    'competent',
    'competition',
    'competitive',
    'complacent',
    'complaining',
    'complete',
    'completed',
    'complex',
    'compliant',
    'complicated',
    'compliment',
    'complimentary',
    'compound',
    'comprehensive',
    'compulsive',
    'compulsory',
    'computer',
    'computerized',
    'concealable',
    'concealed',
    'conceited',
    'conceivable',
    'conceived',
    'concentration',
    'concept',
    'concern',
    'concerned',
    'concerning',
    'concerted',
    'concise',
    'conclusion',
    'concurrent',
    'condemned',
    'condensed',
    'condescending',
    'condition',
    'conditional',
    'conference',
    'confidence',
    'confident',
    'confidential',
    'confirmable',
    'confirmed',
    'conflict',
    'conflicted',
    'conflicting',
    'conformable',
    'confounded',
    'confused',
    'confusing',
    'congenial',
    'congested',
    'congress',
    'congressional',
    'congruent',
    'congruous',
    'connect',
    'connectable',
    'connected',
    'connecting',
    'connection',
    'connective',
    'conscientious',
    'conscious',
    'consecutive',
    'consensual',
    'consenting',
    'consequence',
    'conservative',
    'considerable',
    'considerate',
    'consideration',
    'considered',
    'consistent',
    'consoling',
    'consonant',
    'conspicuous',
    'conspiratorial',
    'constant',
    'constitution',
    'constitutional',
    'constrictive',
    'construct',
    'construction',
    'constructive',
    'consumable',
    'consumer',
    'consummate',
    'contact',
    'contagious',
    'containable',
    'contemplative',
    'contemporary',
    'contemptible',
    'contemptuous',
    'content',
    'contented',
    'contentious',
    'context',
    'contextual',
    'continual',
    'continuing',
    'continuous',
    'contoured',
    'contract',
    'contractual',
    'contradicting',
    'contradictory',
    'contrarian',
    'contrary',
    'contrast',
    'contribution',
    'contributive',
    'contrite',
    'control',
    'controllable',
    'controlling',
    'controversial',
    'convenient',
    'convention',
    'conventional',
    'conversation',
    'conversational',
    'convinced',
    'convincing',
    'convoluted',
    'convulsive',
    'cooing',
    'cooked',
    'cool',
    'coolest',
    'cooperative',
    'coordinated',
    'copious',
    'copy',
    'coquettish',
    'cordial',
    'core',
    'corner',
    'cornered',
    'corny',
    'corporate',
    'corporation',
    'corpulent',
    'correct',
    'correctable',
    'corrective',
    'corresponding',
    'corrosive',
    'corrupt',
    'corrupting',
    'corruptive',
    'cosmetic',
    'cosmic',
    'cost',
    'costly',
    'cottony',
    'coughing',
    'council',
    'country',
    'countryside',
    'county',
    'couple',
    'courage',
    'courageous',
    'course',
    'court',
    'courteous',
    'cover',
    'covert',
    'coveted',
    'cowardly',
    'cowering',
    'coy',
    'cozy',
    'crabby',
    'cracked',
    'crackling',
    'crafted',
    'crafty',
    'craggy',
    'crammed',
    'cramped',
    'cranky',
    'crashing',
    'crass',
    'craven',
    'crawling',
    'crazy',
    'creaking',
    'creaky',
    'creamy',
    'create',
    'creation',
    'creative',
    'credible',
    'credit',
    'creeping',
    'creepy',
    'crestfallen',
    'crime',
    'criminal',
    'crippled',
    'crippling',
    'crisis',
    'crisp',
    'crispy',
    'critical',
    'criticism',
    'crooked',
    'cropped',
    'cross',
    'crossed',
    'crotchety',
    'crowd',
    'crowded',
    'crown',
    'crucial',
    'crude',
    'cruel',
    'crumbling',
    'crumbly',
    'crumply',
    'crunchable',
    'crunching',
    'crunchy',
    'crushable',
    'crushed',
    'crusty',
    'cry',
    'crying',
    'cryptic',
    'crystalline',
    'crystallized',
    'cuddly',
    'culpable',
    'cultural',
    'culture',
    'cultured',
    'cumbersome',
    'cumulative',
    'cunning',
    'cup',
    'curable',
    'curative',
    'curious',
    'curly',
    'currency',
    'current',
    'curriculum',
    'curse',
    'cursed',
    'curt',
    'curved',
    'curvy',
    'customary',
    'customer',
    'cut',
    'cute',
    'cutting',
    'cylindrical',
    'cynical',
    'd',
    'dad',
    'daffy',
    'daft',
    'daily',
    'dainty',
    'damage',
    'damaged',
    'damaging',
    'damp',
    'danceable',
    'dandy',
    'danger',
    'dangerous',
    'dapper',
    'daring',
    'dark',
    'darkened',
    'dashing',
    'date',
    'daughter',
    'daughterly',
    'daunting',
    'dawdling',
    'dawn',
    'day',
    'dazed',
    'dazzling',
    'dead',
    'deadly',
    'deadpan',
    'deaf',
    'deafening',
    'deal',
    'dear',
    'death',
    'debatable',
    'debate',
    'debonair',
    'debt',
    'decade',
    'decadent',
    'decayed',
    'decaying',
    'deceitful',
    'deceivable',
    'deceiving',
    'decent',
    'decentralized',
    'deceptive',
    'decimated',
    'decipherable',
    'decision',
    'decisive',
    'decline',
    'declining',
    'decorative',
    'decorous',
    'decrease',
    'decreasing',
    'decrepit',
    'dedicated',
    'deep',
    'deepening',
    'defeat',
    'defeated',
    'defective',
    'defence',
    'defend',
    'defendable',
    'defenseless',
    'defensible',
    'defensive',
    'defiant',
    'deficient',
    'definable',
    'definition',
    'definitive',
    'deformed',
    'degenerative',
    'degraded',
    'degree',
    'dehydrated',
    'dejected',
    'delectable',
    'deliberate',
    'deliberative',
    'delicate',
    'delicious',
    'delighted',
    'delightful',
    'delinquent',
    'delirious',
    'deliverable',
    'delivery',
    'deluded',
    'demand',
    'demanding',
    'demented',
    'democracy',
    'democratic',
    'demolish',
    'demonic',
    'demonstrative',
    'demure',
    'deniable',
    'dense',
    'deny',
    'department',
    'departure',
    'dependable',
    'dependent',
    'deplorable',
    'deploring',
    'depraved',
    'depressed',
    'depressing',
    'depressive',
    'deprived',
    'deputy',
    'deranged',
    'derivative',
    'derogative',
    'derogatory',
    'descend',
    'description',
    'descriptive',
    'deserted',
    'deserved',
    'design',
    'designer',
    'desirable',
    'desire',
    'desirous',
    'desk',
    'desolate',
    'despairing',
    'desperate',
    'despicable',
    'despised',
    'despondent',
    'destroy',
    'destroyed',
    'destructive',
    'detachable',
    'detached',
    'detail',
    'detailed',
    'detectable',
    'determined',
    'detestable',
    'detrimental',
    'devastated',
    'devastating',
    'developed',
    'development',
    'devious',
    'devoted',
    'devout',
    'dexterous',
    'diabolical',
    'diagonal',
    'didactic',
    'diet',
    'difference',
    'different',
    'difficult',
    'difficulty',
    'diffuse',
    'digestive',
    'digital',
    'dignified',
    'digressive',
    'dilapidated',
    'diligent',
    'dim',
    'diminishing',
    'diminutive',
    'dingy',
    'dinner',
    'diplomatic',
    'dire',
    'direct',
    'directed',
    'direction',
    'director',
    'direful',
    'dirty',
    'disabled',
    'disadvantaged',
    'disadvantageous',
    'disaffected',
    'disagreeable',
    'disappearing',
    'disappointed',
    'disappointing',
    'disapprove',
    'disapproving',
    'disarming',
    'disastrous',
    'discarded',
    'discernable',
    'discipline',
    'disciplined',
    'discomfort',
    'disconnect',
    'disconnected',
    'discontented',
    'discordant',
    'discourage',
    'discouraged',
    'discouraging',
    'discourteous',
    'discredited',
    'discreet',
    'discriminating',
    'discriminatory',
    'discussable',
    'discussion',
    'disdainful',
    'disease',
    'diseased',
    'disenchanted',
    'disgraceful',
    'disgruntled',
    'disgusted',
    'disgusting',
    'disheartened',
    'disheartening',
    'dishonest',
    'dishonorable',
    'disillusioned',
    'disinclined',
    'disingenuous',
    'disinterested',
    'disjointed',
    'dislike',
    'dislikeable',
    'disliked',
    'disloyal',
    'dismal',
    'dismissive',
    'disobedient',
    'disorderly',
    'disorganized',
    'disparaging',
    'disparate',
    'dispassionate',
    'dispensable',
    'disperse',
    'displaced',
    'display',
    'displeased',
    'displeasing',
    'disposable',
    'disproportionate',
    'disproved',
    'disputable',
    'disputatious',
    'disputed',
    'disreputable',
    'disrespectful',
    'disruptive',
    'dissatisfied',
    'dissimilar',
    'dissolvable',
    'dissolving',
    'dissonant',
    'dissuasive',
    'distance',
    'distant',
    'distasteful',
    'distinct',
    'distinction',
    'distinctive',
    'distinguished',
    'distracted',
    'distracting',
    'distraught',
    'distressed',
    'distressing',
    'distribution',
    'district',
    'distrustful',
    'disturbed',
    'disturbing',
    'divergent',
    'diverging',
    'diverse',
    'diversified',
    'divide',
    'divided',
    'divine',
    'division',
    'divisive',
    'dizzy',
    'dizzying',
    'do',
    'doable',
    'doctor',
    'document',
    'documentary',
    'dog',
    'dogged',
    'doggish',
    'dogmatic',
    'doleful',
    'dollish',
    'domed',
    'domestic',
    'dominant',
    'domineering',
    'done',
    'door',
    'dorsal',
    'doting',
    'dotted',
    'double',
    'doubt',
    'doubtful',
    'doubting',
    'dovish',
    'dowdy',
    'down',
    'downhearted',
    'downloadable',
    'downtown',
    'downward',
    'dozing',
    'drab',
    'drained',
    'drama',
    'dramatic',
    'drastic',
    'dreaded',
    'dreadful',
    'dream',
    'dreaming',
    'dreamy',
    'dreary',
    'drenched',
    'dress',
    'dressed',
    'dressy',
    'dried',
    'drink',
    'dripping',
    'drivable',
    'drive',
    'driven',
    'driver',
    'droll',
    'drooping',
    'droopy',
    'drowsy',
    'drug',
    'drunk',
    'dry',
    'drying',
    'dual',
    'dubious',
    'due',
    'dulcet',
    'dull',
    'duplicitous',
    'durable',
    'dusk',
    'dusty',
    'dutiful',
    'duty',
    'dwarf',
    'dwarfish',
    'dwindling',
    'dynamic',
    'dysfunctional',
    'e',
    'each',
    'eager',
    'ear',
    'early',
    'earnest',
    'earth',
    'earthshaking',
    'earthy',
    'east',
    'eastern',
    'easy',
    'eatable',
    'eating',
    'eccentric',
    'echoing',
    'ecological',
    'economic',
    'economical',
    'economy',
    'ecstatic',
    'edge',
    'edged',
    'edgy',
    'editable',
    'editor',
    'educated',
    'education',
    'educational',
    'eerie',
    'effacing',
    'effect',
    'effective',
    'effervescent',
    'efficacious',
    'efficiency',
    'efficient',
    'effort',
    'effortless',
    'effusive',
    'egalitarian',
    'egocentric',
    'egomaniacal',
    'egotistical',
    'eighth',
    'elaborate',
    'elastic',
    'elated',
    'elderly',
    'election',
    'electric',
    'electrical',
    'electricity',
    'electrifying',
    'electronic',
    'elegant',
    'element',
    'elementary',
    'elevated',
    'elfish',
    'eligible',
    'elite',
    'eloquent',
    'elusive',
    'emaciated',
    'embarrassed',
    'embarrassing',
    'embattled',
    'embittered',
    'emblematic',
    'emboldened',
    'embroiled',
    'emergency',
    'eminent',
    'emotional',
    'emotionless',
    'emphasis',
    'empire',
    'empirical',
    'employment',
    'empty',
    'enamored',
    'enchanted',
    'enchanting',
    'encourage',
    'encouraged',
    'encouraging',
    'encrusted',
    'end',
    'endangered',
    'endearing',
    'endemic',
    'endless',
    'endurable',
    'enduring',
    'enemy',
    'energetic',
    'energizing',
    'energy',
    'enforceable',
    'engaging',
    'engine',
    'english',
    'engrossing',
    'enhanced',
    'enigmatic',
    'enjoyable',
    'enlarged',
    'enlightened',
    'enormous',
    'enraged',
    'ensuing',
    'enter',
    'enterprise',
    'enterprising',
    'entertained',
    'entertaining',
    'enthralled',
    'enthused',
    'enthusiastic',
    'enticing',
    'entire',
    'entranced',
    'entrepreneurial',
    'entry',
    'enumerable',
    'enviable',
    'envious',
    'environment',
    'environmental',
    'episodic',
    'equable',
    'equal',
    'equidistant',
    'equipment',
    'equipped',
    'equitable',
    'equivalent',
    'erasable',
    'erect',
    'eroding',
    'errant',
    'erratic',
    'erroneous',
    'error',
    'eruptive',
    'escalating',
    'esoteric',
    'essential',
    'established',
    'establishment',
    'estate',
    'estimated',
    'estranged',
    'eternal',
    'ethereal',
    'ethical',
    'ethnic',
    'euphemistic',
    'euphoric',
    'evasive',
    'even',
    'evenhanded',
    'evening',
    'event',
    'eventful',
    'eventual',
    'everlasting',
    'every',
    'evidence',
    'evil',
    'evocative',
    'exacerbating',
    'exact',
    'exacting',
    'exaggerated',
    'exalted',
    'examination',
    'example',
    'exasperated',
    'exasperating',
    'excellent',
    'exceptional',
    'excessive',
    'exchange',
    'exchangeable',
    'excitable',
    'excited',
    'exciting',
    'exclude',
    'exclusive',
    'excruciating',
    'excusable',
    'executable',
    'executive',
    'exemplary',
    'exercise',
    'exhausted',
    'exhausting',
    'exhaustive',
    'exhibition',
    'exhilarated',
    'exhilarating',
    'existence',
    'existing',
    'exit',
    'exotic',
    'expand',
    'expandable',
    'expanded',
    'expanding',
    'expansion',
    'expansive',
    'expectant',
    'expected',
    'expedient',
    'expeditious',
    'expendable',
    'expenditure',
    'expensive',
    'experience',
    'experimental',
    'expert',
    'expired',
    'expiring',
    'explainable',
    'explanation',
    'explicit',
    'exploding',
    'exploitative',
    'exploited',
    'explosive',
    'exponential',
    'exposed',
    'express',
    'expression',
    'expressionistic',
    'expressionless',
    'expressive',
    'exquisite',
    'extemporaneous',
    'extendable',
    'extended',
    'extension',
    'extensive',
    'extent',
    'exterior',
    'external',
    'extra',
    'extraneous',
    'extraordinary',
    'extravagant',
    'extreme',
    'exuberant',
    'eye',
    'eyed',
    'f',
    'fabled',
    'fabulous',
    'face',
    'facetious',
    'facial',
    'fact',
    'factitious',
    'factor',
    'factory',
    'factual',
    'faded',
    'fading',
    'failed',
    'failure',
    'faint',
    'fainthearted',
    'fair',
    'faith',
    'faithful',
    'faithless',
    'fall',
    'fallacious',
    'false',
    'falsified',
    'faltering',
    'familiar',
    'family',
    'famished',
    'famous',
    'fanatical',
    'fanciful',
    'fancy',
    'fantastic',
    'far',
    'faraway',
    'farcical',
    'farm',
    'farsighted',
    'fascinated',
    'fascinating',
    'fascistic',
    'fashion',
    'fashionable',
    'fashioned',
    'fast',
    'fastest',
    'fastidious',
    'fat',
    'fatal',
    'fated',
    'fateful',
    'father',
    'fatherly',
    'fathomable',
    'fathomless',
    'fatigued',
    'faulty',
    'favorable',
    'favorite',
    'favour',
    'fawning',
    'fear',
    'feared',
    'fearful',
    'fearless',
    'fearsome',
    'feathered',
    'feathery',
    'feature',
    'feckless',
    'federal',
    'feeble',
    'feebleminded',
    'feeling',
    'feigned',
    'felonious',
    'female',
    'feminine',
    'fermented',
    'ferocious',
    'fertile',
    'fervent',
    'fervid',
    'festive',
    'fetching',
    'fetid',
    'feudal',
    'feverish',
    'fewer',
    'fictional',
    'fictitious',
    'fidgeting',
    'fidgety',
    'field',
    'fiendish',
    'fierce',
    'fiery',
    'fifth',
    'fig',
    'figure',
    'file',
    'film',
    'filmy',
    'filtered',
    'filthy',
    'final',
    'finance',
    'financial',
    'find',
    'fine',
    'finicky',
    'finite',
    'fire',
    'fireproof',
    'firm',
    'first',
    'fiscal',
    'fish',
    'fishy',
    'fisted',
    'fit',
    'fitted',
    'fitting',
    'fixable',
    'fixed',
    'flabby',
    'flagrant',
    'flaky',
    'flamboyant',
    'flaming',
    'flammable',
    'flashy',
    'flat',
    'flattened',
    'flattered',
    'flattering',
    'flavored',
    'flavorful',
    'flavorless',
    'flawed',
    'flawless',
    'fleeting',
    'flexible',
    'flickering',
    'flight',
    'flimsy',
    'flippant',
    'flirtatious',
    'float',
    'floating',
    'flooded',
    'floor',
    'floppy',
    'floral',
    'flow',
    'flowering',
    'flowery',
    'fluent',
    'fluffy',
    'flung',
    'flushed',
    'fluttering',
    'flying',
    'foamy',
    'focus',
    'focused',
    'foggy',
    'folded',
    'following',
    'fond',
    'food',
    'foolhardy',
    'foolish',
    'foot',
    'football',
    'footed',
    'forbidding',
    'force',
    'forceful',
    'foreboding',
    'foregoing',
    'foreground',
    'foreign',
    'forensic',
    'foreseeable',
    'forest',
    'forged',
    'forgetful',
    'forgettable',
    'forgivable',
    'forgive',
    'forgiving',
    'forgotten',
    'forked',
    'form',
    'formal',
    'formation',
    'formative',
    'former',
    'formidable',
    'formless',
    'formulaic',
    'forthright',
    'fortuitous',
    'fortunate',
    'forward',
    'foul',
    'found',
    'foundation',
    'founded',
    'fourth',
    'foxy',
    'fractional',
    'fractious',
    'fragile',
    'fragmented',
    'fragrant',
    'frail',
    'framework',
    'frank',
    'frantic',
    'fraternal',
    'fraudulent',
    'frayed',
    'freakish',
    'freaky',
    'freckled',
    'free',
    'freedom',
    'freezing',
    'frequent',
    'fresh',
    'fretful',
    'fried',
    'friend',
    'friendly',
    'frightened',
    'frightening',
    'frightful',
    'frigid',
    'frilly',
    'frisky',
    'frivolous',
    'front',
    'frosty',
    'frothy',
    'frowning',
    'frozen',
    'frugal',
    'fruit',
    'fruitful',
    'fruitless',
    'fruity',
    'frumpy',
    'frustrated',
    'frustrating',
    'fuel',
    'fulfilled',
    'fulfilling',
    'full',
    'fully',
    'fumbling',
    'fuming',
    'fun',
    'function',
    'functional',
    'functioning',
    'fund',
    'fundamental',
    'funniest',
    'funny',
    'furious',
    'furniture',
    'furry',
    'furthest',
    'furtive',
    'fussy',
    'futile',
    'future',
    'futuristic',
    'fuzzy',
    'g',
    'gabby',
    'gainful',
    'gallant',
    'gallery',
    'galling',
    'game',
    'gangly',
    'gap',
    'gaping',
    'garbled',
    'garde',
    'garden',
    'gargantuan',
    'garish',
    'garrulous',
    'gas',
    'gaseous',
    'gasping',
    'gate',
    'gaudy',
    'gaunt',
    'gauzy',
    'gawky',
    'general',
    'generation',
    'generative',
    'generic',
    'generous',
    'genial',
    'gentle',
    'gentleman',
    'genuine',
    'geographic',
    'geologic',
    'geometric',
    'geriatric',
    'ghastly',
    'ghostly',
    'ghoulish',
    'giant',
    'giddy',
    'gifted',
    'gigantic',
    'giggling',
    'gilded',
    'girl',
    'giving',
    'glad',
    'glamorous',
    'glaring',
    'glass',
    'glassy',
    'gleaming',
    'glib',
    'glistening',
    'glittering',
    'global',
    'globular',
    'gloomy',
    'glorious',
    'glossy',
    'glowing',
    'gluey',
    'glum',
    'gluttonous',
    'gnarly',
    'go',
    'goal',
    'god',
    'gold',
    'golden',
    'golf',
    'good',
    'gooey',
    'goofy',
    'gorgeous',
    'government',
    'graceful',
    'gracious',
    'gradual',
    'graham',
    'grainy',
    'grand',
    'grandiose',
    'grant',
    'graphic',
    'grass',
    'grateful',
    'gratified',
    'gratifying',
    'grating',
    'gratis',
    'gratuitous',
    'grave',
    'gray',
    'greasy',
    'great',
    'greatest',
    'greedy',
    'green',
    'gregarious',
    'grey',
    'grieving',
    'grim',
    'grimacing',
    'grimy',
    'grinding',
    'grinning',
    'gripping',
    'gritty',
    'grizzled',
    'groaning',
    'groggy',
    'groomed',
    'groovy',
    'gross',
    'grotesque',
    'grouchy',
    'group',
    'growling',
    'grown',
    'growth',
    'grubbing',
    'grubby',
    'grueling',
    'gruesome',
    'gruff',
    'grumbling',
    'grumpy',
    'guaranteed',
    'guarded',
    'guest',
    'guide',
    'guilt',
    'guiltless',
    'guilty',
    'gullible',
    'gun',
    'gurgling',
    'gushing',
    'gushy',
    'gusty',
    'gutsy',
    'guy',
    'h',
    'habitable',
    'habitual',
    'haggard',
    'hair',
    'hairless',
    'hairy',
    'half',
    'halfhearted',
    'hall',
    'hallowed',
    'halting',
    'hand',
    'handed',
    'handsome',
    'handy',
    'hanging',
    'haphazard',
    'hapless',
    'happiness',
    'happy',
    'hard',
    'hardworking',
    'hardy',
    'harebrained',
    'harmful',
    'harmless',
    'harmonic',
    'harmonious',
    'harried',
    'harsh',
    'hasty',
    'hated',
    'hateful',
    'haughty',
    'haunting',
    'hawkish',
    'hazardous',
    'hazy',
    'head',
    'headed',
    'heady',
    'health',
    'healthy',
    'heart',
    'heartbreaking',
    'heartbroken',
    'hearted',
    'heartless',
    'heartrending',
    'hearty',
    'heat',
    'heated',
    'heaven',
    'heavenly',
    'heavy',
    'hectic',
    'heeled',
    'hefty',
    'height',
    'heinous',
    'hell',
    'help',
    'helpful',
    'helpless',
    'henry',
    'hero',
    'heroic',
    'hesitant',
    'hideous',
    'high',
    'highest',
    'highfalutin',
    'hilarious',
    'hill',
    'hissing',
    'historical',
    'history',
    'hoarse',
    'hoc',
    'hoggish',
    'hole',
    'holiday',
    'holistic',
    'hollow',
    'home',
    'homeless',
    'homely',
    'homeopathic',
    'homey',
    'homo',
    'homogeneous',
    'honed',
    'honest',
    'honking',
    'honorable',
    'hope',
    'hopeful',
    'hopeless',
    'horizontal',
    'hormonal',
    'horned',
    'horrendous',
    'horrible',
    'horrid',
    'horrific',
    'horrified',
    'horrifying',
    'horse',
    'hospitable',
    'hospital',
    'host',
    'hostile',
    'hot',
    'hotel',
    'hotheaded',
    'hour',
    'house',
    'household',
    'howling',
    'huffy',
    'huge',
    'huggable',
    'hulking',
    'human',
    'humanitarian',
    'humanlike',
    'humble',
    'humdrum',
    'humid',
    'humiliated',
    'humiliating',
    'humming',
    'humongous',
    'humored',
    'humorless',
    'humorous',
    'hungry',
    'hurried',
    'hurt',
    'hurtful',
    'husband',
    'hushed',
    'husky',
    'hydraulic',
    'hydrothermal',
    'hygienic',
    'hyper',
    'hyperbolic',
    'hypercritical',
    'hyperirritable',
    'hypersensitive',
    'hypertensive',
    'hypnotic',
    'hypnotizable',
    'hypothetical',
    'hysterical',
    'i',
    'ice',
    'icky',
    'iconoclastic',
    'icy',
    'idea',
    'ideal',
    'idealistic',
    'identical',
    'identifiable',
    'identity',
    'idiosyncratic',
    'idiotic',
    'idyllic',
    'ignorable',
    'ignorance',
    'ignorant',
    'ill',
    'illegal',
    'illegible',
    'illegitimate',
    'illicit',
    'illiterate',
    'illogical',
    'illuminating',
    'illusive',
    'illustrious',
    'image',
    'imaginable',
    'imaginary',
    'imaginative',
    'imitative',
    'immaculate',
    'immanent',
    'immature',
    'immeasurable',
    'immediate',
    'immense',
    'immensurable',
    'imminent',
    'immobile',
    'immodest',
    'immoral',
    'immortal',
    'immovable',
    'impact',
    'impartial',
    'impassable',
    'impassioned',
    'impatient',
    'impeccable',
    'impenetrable',
    'imperative',
    'imperceptible',
    'imperceptive',
    'imperfect',
    'imperial',
    'imperialistic',
    'impermeable',
    'impersonal',
    'impertinent',
    'impervious',
    'impetuous',
    'impish',
    'implausible',
    'implicit',
    'implosive',
    'impolite',
    'imponderable',
    'importance',
    'important',
    'imported',
    'imposing',
    'impossible',
    'impoverished',
    'impractical',
    'imprecise',
    'impression',
    'impressionable',
    'impressive',
    'improbable',
    'improper',
    'improvable',
    'improved',
    'improvement',
    'improving',
    'imprudent',
    'impulsive',
    'impure',
    'in',
    'inaccessible',
    'inaccurate',
    'inactive',
    'inadequate',
    'inadmissible',
    'inadvertent',
    'inadvisable',
    'inalienable',
    'inalterable',
    'inane',
    'inanimate',
    'inapplicable',
    'inappropriate',
    'inapt',
    'inarguable',
    'inarticulate',
    'inartistic',
    'inattentive',
    'inaudible',
    'inauspicious',
    'incalculable',
    'incandescent',
    'incapable',
    'incessant',
    'incident',
    'incidental',
    'include',
    'inclusive',
    'incoherent',
    'income',
    'incomparable',
    'incompatible',
    'incompetent',
    'incomplete',
    'incomprehensible',
    'inconceivable',
    'inconclusive',
    'incongruent',
    'incongruous',
    'inconsequential',
    'inconsiderable',
    'inconsiderate',
    'inconsistent',
    'inconsolable',
    'inconspicuous',
    'incontrovertible',
    'inconvenient',
    'incorrect',
    'incorrigible',
    'incorruptible',
    'increase',
    'increasing',
    'incredible',
    'incredulous',
    'incremental',
    'incurable',
    'indecent',
    'indecipherable',
    'indecisive',
    'indefensible',
    'indefinable',
    'indefinite',
    'indelible',
    'independence',
    'independent',
    'indescribable',
    'indestructible',
    'indeterminable',
    'indeterminate',
    'index',
    'indicative',
    'indifferent',
    'indigenous',
    'indignant',
    'indirect',
    'indiscreet',
    'indiscriminate',
    'indispensable',
    'indisputable',
    'indistinct',
    'individual',
    'individualistic',
    'indivisible',
    'indomitable',
    'inductive',
    'indulgent',
    'industrial',
    'industrious',
    'industry',
    'ineffective',
    'ineffectual',
    'inefficient',
    'inelegant',
    'ineloquent',
    'inequitable',
    'inert',
    'inescapable',
    'inevitable',
    'inexact',
    'inexcusable',
    'inexhaustible',
    'inexpedient',
    'inexpensive',
    'inexplicable',
    'inexpressible',
    'inexpressive',
    'inextricable',
    'infallible',
    'infamous',
    'infantile',
    'infatuated',
    'infected',
    'infectious',
    'inferable',
    'inferior',
    'infernal',
    'infinite',
    'infinitesimal',
    'inflamed',
    'inflammable',
    'inflammatory',
    'inflatable',
    'inflated',
    'inflation',
    'inflexible',
    'influence',
    'influential',
    'informal',
    'information',
    'informative',
    'informed',
    'infrequent',
    'infuriated',
    'infuriating',
    'ingenious',
    'ingenuous',
    'inglorious',
    'ingratiating',
    'inhabitable',
    'inharmonious',
    'inherent',
    'inhibited',
    'inhospitable',
    'inhuman',
    'inhumane',
    'initial',
    'initiative',
    'injudicious',
    'injured',
    'injurious',
    'injury',
    'innate',
    'inner',
    'innocent',
    'innocuous',
    'innovative',
    'innumerable',
    'inoffensive',
    'inoperable',
    'inoperative',
    'inopportune',
    'inordinate',
    'inorganic',
    'inquiring',
    'inquiry',
    'inquisitive',
    'insane',
    'insatiable',
    'inscrutable',
    'insecure',
    'insensible',
    'insensitive',
    'inseparable',
    'inside',
    'insidious',
    'insightful',
    'insignificant',
    'insincere',
    'insipid',
    'insistent',
    'insolent',
    'inspirational',
    'inspired',
    'inspiring',
    'instance',
    'instant',
    'instantaneous',
    'instinctive',
    'instinctual',
    'institute',
    'institution',
    'institutional',
    'instructive',
    'instrumental',
    'insubordinate',
    'insufferable',
    'insufficient',
    'insult',
    'insulted',
    'insulting',
    'insurable',
    'insurance',
    'insurmountable',
    'intangible',
    'integral',
    'intellectual',
    'intelligence',
    'intelligent',
    'intelligible',
    'intended',
    'intense',
    'intensive',
    'intention',
    'intentional',
    'intentioned',
    'interactive',
    'interchangeable',
    'interdepartmental',
    'interdependent',
    'interest',
    'interested',
    'interesting',
    'interior',
    'intermediate',
    'intermittent',
    'internal',
    'international',
    'interpersonal',
    'interpretation',
    'interracial',
    'interview',
    'intestinal',
    'intimate',
    'intimidating',
    'intolerable',
    'intolerant',
    'intravenous',
    'intrepid',
    'intricate',
    'intrigued',
    'intriguing',
    'intrinsic',
    'introduction',
    'introductory',
    'introspective',
    'introverted',
    'intrusive',
    'intuitive',
    'invalid',
    'invaluable',
    'invasive',
    'inventive',
    'investigation',
    'investment',
    'invigorating',
    'invincible',
    'invisible',
    'invited',
    'inviting',
    'involuntary',
    'involved',
    'involvement',
    'inward',
    'irascible',
    'irate',
    'iridescent',
    'irksome',
    'iron',
    'ironic',
    'irrational',
    'irreconcilable',
    'irrefutable',
    'irregular',
    'irrelative',
    'irrelevant',
    'irremovable',
    'irreparable',
    'irreplaceable',
    'irrepressible',
    'irresistible',
    'irresponsible',
    'irretrievably',
    'irreverent',
    'irreversible',
    'irrevocable',
    'irritable',
    'irritated',
    'irritating',
    'island',
    'isolated',
    'issue',
    'itchy',
    'item',
    'itty',
    'j',
    'jabbering',
    'jack',
    'jaded',
    'jagged',
    'jane',
    'japan',
    'jarring',
    'jaundiced',
    'jazzy',
    'jealous',
    'jeering',
    'jerky',
    'jiggling',
    'jittery',
    'job',
    'jobless',
    'jocular',
    'joe',
    'john',
    'join',
    'joint',
    'jolly',
    'jones',
    'journey',
    'jovial',
    'joyful',
    'joyless',
    'joyous',
    'jubilant',
    'judge',
    'judgmental',
    'judicious',
    'juicy',
    'jumbled',
    'jumpy',
    'junior',
    'just',
    'justice',
    'justifiable',
    'juvenile',
    'k',
    'kaput',
    'keen',
    'kempt',
    'key',
    'kind',
    'kindhearted',
    'kindly',
    'kinesthetic',
    'king',
    'kingdom',
    'kingly',
    'kitchen',
    'knavish',
    'knightly',
    'knobbed',
    'knobby',
    'knotty',
    'knowable',
    'knowing',
    'knowledge',
    'knowledgeable',
    'known',
    'l',
    'labored',
    'laborious',
    'labour',
    'lack',
    'lackadaisical',
    'lacking',
    'lacy',
    'lady',
    'lake',
    'lame',
    'lamentable',
    'land',
    'lane',
    'language',
    'languid',
    'languishing',
    'lanky',
    'larcenous',
    'large',
    'larger',
    'largest',
    'lascivious',
    'last',
    'lasting',
    'late',
    'latent',
    'later',
    'lateral',
    'latest',
    'latter',
    'laudable',
    'laugh',
    'laughable',
    'laughing',
    'lavish',
    'law',
    'lawful',
    'lawless',
    'lax',
    'lazy',
    'lead',
    'leader',
    'leadership',
    'leading',
    'league',
    'lean',
    'learnable',
    'learned',
    'leased',
    'least',
    'leather',
    'leathery',
    'lecherous',
    'lee',
    'leering',
    'left',
    'leg',
    'legal',
    'legendary',
    'legible',
    'legislation',
    'legislative',
    'legitimate',
    'lend',
    'length',
    'lengthy',
    'lenient',
    'less',
    'lesser',
    'lethal',
    'lethargic',
    'letter',
    'level',
    'lewis',
    'liability',
    'liable',
    'libelous',
    'liberal',
    'library',
    'licence',
    'licensed',
    'life',
    'lifeless',
    'lifelike',
    'lifelong',
    'lifespan',
    'light',
    'lighthearted',
    'likable',
    'like',
    'likeable',
    'liked',
    'likely',
    'lily',
    'limber',
    'limit',
    'limited',
    'limitless',
    'limp',
    'limping',
    'line',
    'linear',
    'lined',
    'lingering',
    'linguistic',
    'link',
    'liquid',
    'list',
    'listless',
    'lit',
    'literal',
    'literary',
    'literate',
    'literature',
    'lithe',
    'lithographic',
    'litigious',
    'livable',
    'live',
    'lived',
    'lively',
    'livered',
    'livid',
    'living',
    'loan',
    'loathsome',
    'local',
    'locatable',
    'location',
    'locked',
    'lofty',
    'logarithmic',
    'logical',
    'logistic',
    'lonely',
    'long',
    'longer',
    'longest',
    'longing',
    'look',
    'looking',
    'loose',
    'lopsided',
    'loquacious',
    'lord',
    'lordly',
    'loss',
    'lost',
    'lot',
    'loud',
    'lousy',
    'loutish',
    'lovable',
    'love',
    'loveable',
    'lovely',
    'loving',
    'low',
    'lower',
    'lowly',
    'loyal',
    'lucent',
    'lucid',
    'lucky',
    'lucrative',
    'ludicrous',
    'lukewarm',
    'lulling',
    'luminescent',
    'luminous',
    'lumpy',
    'lunch',
    'lurid',
    'luscious',
    'lush',
    'lustrous',
    'luxurious',
    'lying',
    'lyrical',
    'm',
    'macabre',
    'machiavellian',
    'machine',
    'macho',
    'mad',
    'maddening',
    'made',
    'magazine',
    'magenta',
    'magic',
    'magical',
    'magnanimous',
    'magnetic',
    'magnificent',
    'maiden',
    'main',
    'maintainable',
    'maintained',
    'maintenance',
    'majestic',
    'major',
    'majority',
    'makeable',
    'makeshift',
    'maladjusted',
    'male',
    'malevolent',
    'malicious',
    'malignant',
    'malleable',
    'mammoth',
    'man',
    'manageable',
    'management',
    'manager',
    'managerial',
    'manchester',
    'mandatory',
    'maneuverable',
    'mangy',
    'maniacal',
    'manic',
    'manicured',
    'manipulative',
    'manner',
    'mannered',
    'manual',
    'map',
    'marbled',
    'march',
    'marginal',
    'mark',
    'marked',
    'market',
    'marketable',
    'marriage',
    'married',
    'martin',
    'marvelous',
    'mary',
    'masked',
    'mass',
    'massive',
    'master',
    'masterful',
    'match',
    'matchless',
    'material',
    'materialistic',
    'maternal',
    'mathematical',
    'matronly',
    'matted',
    'mature',
    'maximum',
    'may',
    'meager',
    'meal',
    'mean',
    'meandering',
    'meaning',
    'meaningful',
    'meaningless',
    'measly',
    'measurable',
    'measure',
    'meat',
    'meaty',
    'mechanical',
    'medical',
    'medicinal',
    'meditative',
    'medium',
    'meek',
    'melancholy',
    'mellow',
    'melodic',
    'melodious',
    'melodramatic',
    'melted',
    'member',
    'membership',
    'memorable',
    'memory',
    'menacing',
    'menial',
    'mental',
    'merciful',
    'merciless',
    'mercurial',
    'mere',
    'merry',
    'message',
    'messy',
    'metabolic',
    'metal',
    'metallic',
    'metaphoric',
    'meteoric',
    'method',
    'meticulous',
    'microscopic',
    'microwaveable',
    'middle',
    'midweek',
    'mighty',
    'mike',
    'mild',
    'militant',
    'militaristic',
    'military',
    'milk',
    'milky',
    'mill',
    'mincing',
    'mind',
    'minded',
    'mindful',
    'mindless',
    'mini',
    'miniature',
    'minimal',
    'minimum',
    'minister',
    'ministry',
    'minor',
    'minority',
    'minute',
    'miraculous',
    'mirror',
    'mirthful',
    'miscellaneous',
    'mischievous',
    'miscreant',
    'miserable',
    'miserly',
    'misguided',
    'misleading',
    'miss',
    'mission',
    'mistake',
    'mistaken',
    'mistrustful',
    'mistrusting',
    'misty',
    'mixed',
    'mnemonic',
    'moaning',
    'mobile',
    'mocking',
    'model',
    'moderate',
    'modern',
    'modest',
    'modified',
    'modular',
    'moist',
    'moldy',
    'moment',
    'momentary',
    'momentous',
    'monetary',
    'money',
    'monopolistic',
    'monosyllabic',
    'monotone',
    'monotonous',
    'monstrous',
    'month',
    'monumental',
    'moody',
    'moral',
    'moralistic',
    'morbid',
    'mordant',
    'more',
    'morning',
    'moronic',
    'morose',
    'mortal',
    'mortified',
    'mother',
    'motherly',
    'motion',
    'motionless',
    'motivated',
    'motivating',
    'motivational',
    'motor',
    'mountain',
    'mountainous',
    'mournful',
    'mouth',
    'mouthwatering',
    'movable',
    'move',
    'moved',
    'movement',
    'moving',
    'muddled',
    'muddy',
    'muffled',
    'muggy',
    'multicultural',
    'multifaceted',
    'multipurpose',
    'multitalented',
    'mum',
    'mumbled',
    'mundane',
    'municipal',
    'murder',
    'murky',
    'muscular',
    'museum',
    'mushy',
    'music',
    'musical',
    'musky',
    'musty',
    'mutative',
    'mute',
    'muted',
    'mutinous',
    'muttering',
    'mutual',
    'myopic',
    'mysterious',
    'mystic',
    'mystical',
    'mystified',
    'mystifying',
    'mythical',
    'n',
    'nadir',
    'naive',
    'name',
    'nameless',
    'narcissistic',
    'narrow',
    'nasal',
    'nasty',
    'nation',
    'national',
    'native',
    'natural',
    'nature',
    'natured',
    'naughty',
    'nauseating',
    'nauseous',
    'nautical',
    'navigable',
    'navy',
    'near',
    'nearby',
    'nearest',
    'nearsighted',
    'neat',
    'nebulous',
    'necessary',
    'neck',
    'need',
    'needless',
    'needy',
    'nefarious',
    'negative',
    'neglected',
    'neglectful',
    'negligent',
    'negligible',
    'negotiable',
    'neighborly',
    'nerve',
    'nervous',
    'network',
    'neurological',
    'neurotic',
    'neutral',
    'never',
    'new',
    'newest',
    'news',
    'newspaper',
    'next',
    'nice',
    'nifty',
    'night',
    'nightmarish',
    'nimble',
    'ninth',
    'nippy',
    'no',
    'noble',
    'nocturnal',
    'noise',
    'noiseless',
    'noisy',
    'nominal',
    'nonabrasive',
    'nonaggressive',
    'nonchalant',
    'noncommittal',
    'noncompetitive',
    'nonconsecutive',
    'nondescript',
    'nondestructive',
    'nonexclusive',
    'nonnegotiable',
    'nonproductive',
    'nonrefundable',
    'nonrenewable',
    'nonresponsive',
    'nonrestrictive',
    'nonreturnable',
    'nonsensical',
    'nonspecific',
    'nonstop',
    'nontransferable',
    'nonverbal',
    'nonviolent',
    'normal',
    'north',
    'northeast',
    'northerly',
    'northern',
    'northwest',
    'nose',
    'nostalgic',
    'nosy',
    'notable',
    'note',
    'notice',
    'noticeable',
    'notion',
    'notorious',
    'novel',
    'noxious',
    'null',
    'numb',
    'numberless',
    'numbing',
    'numerable',
    'numeric',
    'numerous',
    'nutritional',
    'nutritious',
    'nutty',
    'o',
    'oafish',
    'obedient',
    'obeisant',
    'obese',
    'object',
    'objectionable',
    'objective',
    'obligatory',
    'obliging',
    'oblique',
    'oblivious',
    'oblong',
    'obnoxious',
    'obscene',
    'obscure',
    'observable',
    'observant',
    'obsessive',
    'obsolete',
    'obstinate',
    'obstructive',
    'obtainable',
    'obtrusive',
    'obtuse',
    'obvious',
    'occasion',
    'occasional',
    'occupational',
    'occupied',
    'oceanic',
    'odd',
    'odiferous',
    'odious',
    'odorless',
    'odorous',
    'of',
    'off',
    'offbeat',
    'offence',
    'offensive',
    'offer',
    'offhanded',
    'office',
    'officer',
    'official',
    'officious',
    'oil',
    'oily',
    'okay',
    'old',
    'older',
    'oldest',
    'ominous',
    'omniscient',
    'omnivorous',
    'one',
    'onerous',
    'only',
    'opaque',
    'open',
    'opened',
    'openhanded',
    'openhearted',
    'opening',
    'operable',
    'operatic',
    'operation',
    'operational',
    'operative',
    'opinion',
    'opinionated',
    'opportune',
    'opportunistic',
    'opportunity',
    'opposable',
    'opposed',
    'opposing',
    'opposite',
    'opposition',
    'oppressive',
    'optimal',
    'optimist',
    'optimistic',
    'option',
    'optional',
    'opulent',
    'oral',
    'orange',
    'order',
    'ordinary',
    'organic',
    'organisation',
    'organization',
    'organizational',
    'oriented',
    'original',
    'ornamental',
    'ornate',
    'ornery',
    'orphaned',
    'orthopedic',
    'ossified',
    'ostentatious',
    'other',
    'otherwise',
    'out',
    'outcome',
    'outer',
    'outermost',
    'outgoing',
    'outlandish',
    'output',
    'outraged',
    'outrageous',
    'outside',
    'outspoken',
    'outstanding',
    'outward',
    'oval',
    'overactive',
    'overaggressive',
    'overall',
    'overambitious',
    'overassertive',
    'overbearing',
    'overcast',
    'overcautious',
    'overconfident',
    'overcritical',
    'overcrowded',
    'overemotional',
    'overenthusiastic',
    'overjoyed',
    'overoptimistic',
    'overpowering',
    'overpriced',
    'overprotective',
    'overqualified',
    'overrated',
    'oversensitive',
    'oversized',
    'overt',
    'overwhelmed',
    'overwhelming',
    'overworked',
    'overwrought',
    'overzealous',
    'own',
    'owner',
    'oxford',
    'oxymoronic',
    'p',
    'paced',
    'package',
    'padded',
    'page',
    'pain',
    'painful',
    'painless',
    'painstaking',
    'pair',
    'palace',
    'palatable',
    'palatial',
    'pale',
    'pallid',
    'palpable',
    'paltry',
    'pampered',
    'panel',
    'panicky',
    'panoramic',
    'paper',
    'paradoxical',
    'parallel',
    'paranormal',
    'parasitic',
    'parched',
    'pardonable',
    'parent',
    'parental',
    'parenthetic',
    'parish',
    'park',
    'parking',
    'parliament',
    'parsimonious',
    'part',
    'partial',
    'particular',
    'partisan',
    'partner',
    'partnership',
    'party',
    'passage',
    'passing',
    'passionate',
    'passive',
    'past',
    'pastoral',
    'patched',
    'patchy',
    'patented',
    'paternal',
    'paternalistic',
    'path',
    'pathetic',
    'pathological',
    'patient',
    'patriotic',
    'patronizing',
    'pattern',
    'patterned',
    'paul',
    'pay',
    'payable',
    'payment',
    'peace',
    'peaceable',
    'peaceful',
    'peculiar',
    'pedantic',
    'pedestrian',
    'peerless',
    'peeved',
    'peevish',
    'penetrable',
    'penetrating',
    'pension',
    'pensive',
    'peppery',
    'perceivable',
    'perceptible',
    'perceptive',
    'perceptual',
    'peremptory',
    'perennial',
    'perfect',
    'performance',
    'perfumed',
    'perilous',
    'period',
    'periodic',
    'peripheral',
    'perishable',
    'perky',
    'permanent',
    'permeable',
    'permissible',
    'permissive',
    'pernicious',
    'perpendicular',
    'perpetual',
    'perplexed',
    'perplexing',
    'persevering',
    'persistent',
    'person',
    'personable',
    'personal',
    'persuasive',
    'pert',
    'pertinent',
    'perturbed',
    'perturbing',
    'pervasive',
    'perverse',
    'pessimist',
    'pessimistic',
    'peter',
    'petite',
    'pettish',
    'petty',
    'petulant',
    'pharmaceutical',
    'phase',
    'phenomenal',
    'philanthropic',
    'philosophical',
    'philosophy',
    'phobic',
    'phone',
    'phonemic',
    'phonetic',
    'phosphorescent',
    'photographic',
    'physical',
    'physiological',
    'picture',
    'picturesque',
    'piece',
    'piercing',
    'pigheaded',
    'pink',
    'pious',
    'piquant',
    'pitch',
    'pitched',
    'piteous',
    'pithy',
    'pitiful',
    'pitiless',
    'pivotal',
    'place',
    'placed',
    'placid',
    'plaid',
    'plain',
    'plan',
    'plane',
    'planned',
    'plant',
    'plastic',
    'plate',
    'platonic',
    'plausible',
    'play',
    'player',
    'playful',
    'pleading',
    'pleasant',
    'pleased',
    'pleasing',
    'pleasurable',
    'pleasure',
    'plentiful',
    'pliable',
    'plodding',
    'plopping',
    'plucky',
    'plump',
    'pluralistic',
    'plus',
    'plush',
    'pneumatic',
    'poetic',
    'poignant',
    'point',
    'pointless',
    'poised',
    'poisonous',
    'police',
    'policy',
    'polished',
    'polite',
    'political',
    'polka',
    'polluted',
    'pollution',
    'polyunsaturated',
    'pompous',
    'ponderous',
    'pool',
    'poor',
    'poorer',
    'poorest',
    'popping',
    'popular',
    'population',
    'populous',
    'porous',
    'port',
    'portable',
    'portly',
    'position',
    'positive',
    'possessive',
    'possibility',
    'possible',
    'post',
    'posthumous',
    'postoperative',
    'potable',
    'potent',
    'potential',
    'pound',
    'powdery',
    'power',
    'powerful',
    'powerless',
    'pp',
    'practical',
    'practice',
    'pragmatic',
    'praiseworthy',
    'precarious',
    'precious',
    'precipitous',
    'precise',
    'precocious',
    'preconceived',
    'predicative',
    'predictable',
    'predisposed',
    'predominant',
    'preeminent',
    'preemptive',
    'prefabricated',
    'preferable',
    'preferential',
    'pregnant',
    'prehistoric',
    'prejudiced',
    'prejudicial',
    'preliminary',
    'premature',
    'premeditated',
    'premium',
    'prenatal',
    'preoccupied',
    'preoperative',
    'preparative',
    'prepared',
    'preposterous',
    'prescriptive',
    'presence',
    'present',
    'presentable',
    'president',
    'presidential',
    'press',
    'pressing',
    'pressure',
    'pressurized',
    'prestigious',
    'presumable',
    'presumptive',
    'presumptuous',
    'pretend',
    'pretentious',
    'pretty',
    'prevalent',
    'preventable',
    'preventative',
    'preventive',
    'previous',
    'price',
    'priceless',
    'pricey',
    'prickly',
    'prim',
    'primary',
    'primitive',
    'primordial',
    'prince',
    'princely',
    'principal',
    'principle',
    'principled',
    'prior',
    'priority',
    'prison',
    'prissy',
    'pristine',
    'private',
    'prize',
    'prized',
    'proactive',
    'probabilistic',
    'probable',
    'problem',
    'problematic',
    'procedural',
    'procedure',
    'process',
    'prodigious',
    'product',
    'production',
    'productive',
    'profane',
    'professed',
    'professional',
    'professor',
    'professorial',
    'proficient',
    'profit',
    'profitable',
    'profound',
    'profuse',
    'program',
    'programmable',
    'programme',
    'progress',
    'progressive',
    'prohibitive',
    'project',
    'prolific',
    'prominent',
    'promised',
    'promising',
    'prompt',
    'pronounceable',
    'pronounced',
    'proof',
    'proper',
    'property',
    'prophetic',
    'proportion',
    'proportional',
    'proportionate',
    'proportioned',
    'proposal',
    'prospective',
    'prosperous',
    'protection',
    'protective',
    'prototypical',
    'proud',
    'proverbial',
    'provision',
    'provisional',
    'provocative',
    'provoking',
    'proximal',
    'proximate',
    'prudent',
    'prudential',
    'prying',
    'psychedelic',
    'psychiatric',
    'psychological',
    'psychosomatic',
    'psychotic',
    'pub',
    'public',
    'publication',
    'puckish',
    'puffy',
    'pugnacious',
    'pumped',
    'punctual',
    'pungent',
    'punishable',
    'punitive',
    'puny',
    'pure',
    'purified',
    'puritanical',
    'purple',
    'purported',
    'purpose',
    'purposeful',
    'purposeless',
    'purring',
    'pushy',
    'pusillanimous',
    'putrid',
    'puzzled',
    'puzzling',
    'pyrotechnic',
    'q',
    'quackish',
    'quacky',
    'quaint',
    'qualified',
    'qualitative',
    'quality',
    'quantifiable',
    'quantitative',
    'quarrelsome',
    'quarter',
    'queasy',
    'queen',
    'queenly',
    'querulous',
    'question',
    'questionable',
    'quick',
    'quickest',
    'quiet',
    'quintessential',
    'quirky',
    'quivering',
    'quizzical',
    'quotable',
    'r',
    'rabid',
    'race',
    'racial',
    'racist',
    'racking',
    'radiant',
    'radical',
    'radio',
    'radioactive',
    'ragged',
    'raging',
    'rail',
    'railway',
    'rain',
    'rainbow',
    'rainy',
    'rakish',
    'rambling',
    'rambunctious',
    'rampageous',
    'rampant',
    'rancid',
    'rancorous',
    'random',
    'range',
    'ranging',
    'rank',
    'ranking',
    'rapid',
    'rapturous',
    'rare',
    'rascally',
    'rash',
    'rasping',
    'raspy',
    'rate',
    'rational',
    'ratty',
    'ravenous',
    'raving',
    'ravishing',
    'raw',
    'razor',
    'reaction',
    'reactive',
    'read',
    'reader',
    'ready',
    'real',
    'realistic',
    'reality',
    'reason',
    'reasonable',
    'reassured',
    'reassuring',
    'rebel',
    'rebellious',
    'receding',
    'received',
    'recent',
    'receptive',
    'recession',
    'recessive',
    'rechargeable',
    'reciprocal',
    'reckless',
    'reclusive',
    'recognition',
    'recognizable',
    'recognized',
    'record',
    'recovery',
    'rectangular',
    'rectifiable',
    'recurrent',
    'recyclable',
    'red',
    'reddish',
    'redeemable',
    'redolent',
    'reduction',
    'redundant',
    'ref',
    'reference',
    'referential',
    'refillable',
    'reflective',
    'reform',
    'refractive',
    'refreshing',
    'refundable',
    'refurbished',
    'refutable',
    'regal',
    'regime',
    'region',
    'regional',
    'regretful',
    'regrettable',
    'regular',
    'reigning',
    'reject',
    'relatable',
    'relation',
    'relationship',
    'relative',
    'relaxed',
    'relaxing',
    'release',
    'relentless',
    'relevant',
    'reliable',
    'reliant',
    'relief',
    'relieved',
    'religion',
    'religious',
    'reluctant',
    'remaining',
    'remarkable',
    'remedial',
    'reminiscent',
    'remorseful',
    'remorseless',
    'remote',
    'removable',
    'renegotiable',
    'renewable',
    'rented',
    'repair',
    'repairable',
    'repaired',
    'repeatable',
    'repeated',
    'repentant',
    'repetitious',
    'repetitive',
    'replaceable',
    'replicable',
    'report',
    'reported',
    'reprehensible',
    'representation',
    'representative',
    'repressive',
    'reproachful',
    'reproductive',
    'republic',
    'republican',
    'repugnant',
    'repulsive',
    'reputable',
    'reputation',
    'reputed',
    'request',
    'rescued',
    'resealable',
    'research',
    'resentful',
    'reserved',
    'resident',
    'residential',
    'residual',
    'resilient',
    'resistance',
    'resolute',
    'resolution',
    'resolvable',
    'resonant',
    'resounding',
    'resourceful',
    'respect',
    'respectable',
    'respectful',
    'respective',
    'response',
    'responsibility',
    'responsible',
    'responsive',
    'rest',
    'restaurant',
    'rested',
    'restful',
    'restless',
    'restored',
    'restrained',
    'restrictive',
    'result',
    'retired',
    'retirement',
    'retroactive',
    'retrogressive',
    'retrospective',
    'return',
    'reusable',
    'revamped',
    'revealing',
    'revengeful',
    'revenue',
    'reverent',
    'reverential',
    'reverse',
    'reversible',
    'review',
    'reviewable',
    'reviled',
    'revisable',
    'revised',
    'revocable',
    'revolting',
    'revolution',
    'revolutionary',
    'rewarding',
    'rhetorical',
    'rhythmic',
    'rich',
    'richer',
    'richest',
    'ridden',
    'ridiculing',
    'ridiculous',
    'right',
    'righteous',
    'rightful',
    'rigid',
    'rigorous',
    'ring',
    'ringing',
    'riotous',
    'ripe',
    'rippling',
    'rise',
    'risk',
    'risky',
    'ritualistic',
    'ritzy',
    'river',
    'riveting',
    'road',
    'roaring',
    'roasted',
    'robotic',
    'robust',
    'rock',
    'rocketing',
    'roguish',
    'role',
    'romantic',
    'roof',
    'room',
    'roomy',
    'rosy',
    'rotating',
    'rotten',
    'rotting',
    'rotund',
    'rough',
    'round',
    'rounded',
    'roundtable',
    'rousing',
    'route',
    'routine',
    'row',
    'rowdy',
    'royal',
    'ruddy',
    'rude',
    'rudimentary',
    'rueful',
    'rugby',
    'rugged',
    'ruined',
    'ruinous',
    'rule',
    'rumbling',
    'rumpled',
    'run',
    'ruptured',
    'rural',
    'rusted',
    'rustic',
    'rustling',
    'rusty',
    'ruthless',
    'rutted',
    's',
    'saccharin',
    'sacred',
    'sacrificial',
    'sacrilegious',
    'sad',
    'saddened',
    'sadness',
    'safe',
    'safety',
    'saintly',
    'salacious',
    'sale',
    'salient',
    'salt',
    'salted',
    'salty',
    'salvageable',
    'salvaged',
    'same',
    'sample',
    'sanctimonious',
    'sandy',
    'sane',
    'sanguine',
    'sanitary',
    'sapiens',
    'sappy',
    'sarcastic',
    'sardonic',
    'sassy',
    'satin',
    'satiny',
    'satiric',
    'satirical',
    'satisfactory',
    'satisfied',
    'satisfying',
    'saucy',
    'savage',
    'savory',
    'savvy',
    'scalding',
    'scale',
    'scaly',
    'scandalous',
    'scant',
    'scanty',
    'scarce',
    'scared',
    'scarred',
    'scary',
    'scathing',
    'scattered',
    'scene',
    'scenic',
    'scented',
    'scheduled',
    'schematic',
    'scheme',
    'scholarly',
    'scholastic',
    'school',
    'science',
    'scientific',
    'scintillating',
    'scope',
    'scorching',
    'scornful',
    'scrabbled',
    'scraggly',
    'scrappy',
    'scratched',
    'scratchy',
    'scrawny',
    'screaming',
    'screeching',
    'screen',
    'scribbled',
    'scriptural',
    'scruffy',
    'scrumptious',
    'scrupulous',
    'sculpted',
    'sculptural',
    'scummy',
    'sea',
    'sealed',
    'seamless',
    'search',
    'searching',
    'searing',
    'seasick',
    'season',
    'seasonable',
    'seasonal',
    'seat',
    'secluded',
    'second',
    'secondary',
    'secret',
    'secretary',
    'secretive',
    'section',
    'sector',
    'secular',
    'secure',
    'secured',
    'security',
    'sedate',
    'seditious',
    'seductive',
    'seedy',
    'seeming',
    'seemly',
    'seething',
    'seismic',
    'seldom',
    'select',
    'selected',
    'selection',
    'selective',
    'self',
    'selfish',
    'selfless',
    'sell',
    'sellable',
    'semiconscious',
    'semiofficial',
    'semiprecious',
    'semiprofessional',
    'senior',
    'sensational',
    'sense',
    'senseless',
    'sensible',
    'sensitive',
    'sensual',
    'sensuous',
    'sentence',
    'sentimental',
    'separate',
    'sequence',
    'sequential',
    'serendipitous',
    'serene',
    'serial',
    'series',
    'serious',
    'serrated',
    'service',
    'serviceable',
    'session',
    'set',
    'settlement',
    'seventh',
    'severe',
    'sex',
    'shabbiest',
    'shabby',
    'shaded',
    'shadowed',
    'shadowy',
    'shady',
    'shaggy',
    'shaky',
    'shallow',
    'shamefaced',
    'shameful',
    'shameless',
    'shape',
    'shapeless',
    'shapely',
    'share',
    'sharp',
    'sharpened',
    'shattered',
    'shattering',
    'sheepish',
    'sheer',
    'sheet',
    'sheltered',
    'shifty',
    'shimmering',
    'shining',
    'shiny',
    'ship',
    'shivering',
    'shivery',
    'shock',
    'shocked',
    'shocking',
    'shoddy',
    'shop',
    'short',
    'shortsighted',
    'shot',
    'shoulder',
    'show',
    'showy',
    'shrewd',
    'shrieking',
    'shrill',
    'shut',
    'shy',
    'sick',
    'sickened',
    'sickening',
    'sickly',
    'side',
    'sided',
    'sight',
    'sign',
    'signed',
    'significance',
    'significant',
    'silence',
    'silent',
    'silky',
    'silly',
    'silver',
    'simian',
    'similar',
    'simon',
    'simple',
    'simpleminded',
    'simplified',
    'simplistic',
    'simultaneous',
    'sincere',
    'sinful',
    'single',
    'singular',
    'sinister',
    'sink',
    'sinuous',
    'sir',
    'sister',
    'sisterly',
    'site',
    'situation',
    'sixth',
    'sizable',
    'size',
    'sized',
    'sizzling',
    'skeptical',
    'sketchy',
    'skill',
    'skilled',
    'skillful',
    'skimpy',
    'skin',
    'skinny',
    'skittish',
    'sky',
    'slanderous',
    'slanted',
    'slanting',
    'sleek',
    'sleep',
    'sleeping',
    'sleepless',
    'sleepy',
    'slender',
    'slick',
    'slight',
    'slim',
    'slimy',
    'slippery',
    'sloped',
    'sloping',
    'sloppy',
    'slothful',
    'slow',
    'sluggish',
    'slushy',
    'sly',
    'small',
    'smaller',
    'smallest',
    'smarmy',
    'smart',
    'smarter',
    'smartest',
    'smashing',
    'smeared',
    'smelling',
    'smelly',
    'smile',
    'smiling',
    'smith',
    'smoggy',
    'smoked',
    'smoky',
    'smooth',
    'smothering',
    'smudged',
    'smug',
    'snapping',
    'snappish',
    'snappy',
    'snarling',
    'sneaky',
    'snide',
    'snippy',
    'snobbish',
    'snoopy',
    'snooty',
    'snoring',
    'snotty',
    'snow',
    'snug',
    'snuggly',
    'soaked',
    'soaking',
    'soaring',
    'sober',
    'sociable',
    'social',
    'socialist',
    'society',
    'sociological',
    'soft',
    'softhearted',
    'software',
    'soggy',
    'soil',
    'solar',
    'soldierly',
    'sole',
    'solemn',
    'solicitous',
    'solid',
    'solitary',
    'solution',
    'somatic',
    'somber',
    'son',
    'song',
    'sonic',
    'sonly',
    'soothed',
    'soothing',
    'sophisticated',
    'sordid',
    'sore',
    'sorrowful',
    'sorry',
    'sort',
    'soulful',
    'soulless',
    'sound',
    'soundless',
    'sour',
    'source',
    'south',
    'southeasterly',
    'southern',
    'southwestern',
    'space',
    'spacious',
    'spare',
    'sparing',
    'sparkling',
    'sparkly',
    'sparse',
    'spasmodic',
    'spastic',
    'spatial',
    'spattered',
    'speaker',
    'special',
    'specialist',
    'specialized',
    'species',
    'specific',
    'speckled',
    'spectacular',
    'spectral',
    'speculative',
    'speech',
    'speechless',
    'speed',
    'speedy',
    'spellbinding',
    'spendthrift',
    'spherical',
    'spicy',
    'spiffy',
    'spiky',
    'spinal',
    'spineless',
    'spiral',
    'spiraled',
    'spirit',
    'spirited',
    'spiritless',
    'spiritual',
    'spiteful',
    'splashing',
    'splashy',
    'splattered',
    'splendid',
    'splintered',
    'splitting',
    'spoiled',
    'spoken',
    'spokesman',
    'spongy',
    'spontaneous',
    'spooky',
    'sporadic',
    'sport',
    'sporting',
    'sportsmanly',
    'spot',
    'spotless',
    'spotted',
    'spotty',
    'spring',
    'springy',
    'sprite',
    'spry',
    'spurious',
    'squalid',
    'squandered',
    'square',
    'squashed',
    'squashy',
    'squatting',
    'squawking',
    'squealing',
    'squeamish',
    'squeezable',
    'squiggly',
    'squirming',
    'squirrelly',
    'st',
    'stable',
    'stackable',
    'stacked',
    'staff',
    'stage',
    'staggering',
    'stagnant',
    'stained',
    'stale',
    'stanch',
    'standard',
    'standing',
    'standoffish',
    'star',
    'starched',
    'stark',
    'start',
    'startled',
    'startling',
    'starving',
    'state',
    'stately',
    'statement',
    'static',
    'station',
    'statistical',
    'statuesque',
    'status',
    'statutory',
    'staunch',
    'steadfast',
    'steady',
    'stealth',
    'steaming',
    'steamy',
    'steel',
    'steely',
    'steep',
    'step',
    'stereophonic',
    'stereotyped',
    'stereotypical',
    'sterile',
    'stern',
    'sticky',
    'stiff',
    'stifled',
    'stifling',
    'stigmatic',
    'still',
    'stilled',
    'stilted',
    'stimulating',
    'stinging',
    'stingy',
    'stinking',
    'stinky',
    'stirring',
    'stock',
    'stodgy',
    'stoic',
    'stone',
    'stony',
    'store',
    'stormy',
    'stout',
    'straggly',
    'straight',
    'straightforward',
    'stranded',
    'strange',
    'strategic',
    'strategy',
    'streaked',
    'street',
    'strength',
    'strenuous',
    'stress',
    'stressful',
    'stretchy',
    'strict',
    'strident',
    'strike',
    'striking',
    'stringent',
    'striped',
    'strong',
    'stronger',
    'strongest',
    'structural',
    'structure',
    'struggle',
    'stubborn',
    'stubby',
    'stuck',
    'student',
    'studied',
    'studious',
    'study',
    'stuff',
    'stuffed',
    'stuffy',
    'stumbling',
    'stunned',
    'stunning',
    'stupendous',
    'stupid',
    'sturdy',
    'stuttering',
    'style',
    'stylish',
    'stylistic',
    'suave',
    'subconscious',
    'subdued',
    'subject',
    'subjective',
    'sublime',
    'subliminal',
    'submissive',
    'subordinate',
    'subsequent',
    'subservient',
    'substantial',
    'substantiated',
    'substitute',
    'subterranean',
    'subtitled',
    'subtle',
    'subversive',
    'success',
    'successful',
    'successive',
    'succinct',
    'succulent',
    'such',
    'sudden',
    'suffering',
    'sufficient',
    'sugar',
    'sugary',
    'suggestive',
    'suitable',
    'suited',
    'sulky',
    'sullen',
    'sum',
    'summer',
    'sumptuous',
    'sun',
    'sunny',
    'super',
    'superabundant',
    'superb',
    'supercilious',
    'superficial',
    'superhuman',
    'superior',
    'superlative',
    'supernatural',
    'supersensitive',
    'supersonic',
    'superstitious',
    'supple',
    'supply',
    'support',
    'supportive',
    'supposed',
    'suppressive',
    'supreme',
    'sure',
    'surface',
    'surgical',
    'surly',
    'surmountable',
    'surprise',
    'surprised',
    'surprising',
    'surrealistic',
    'survey',
    'survivable',
    'susceptible',
    'suspected',
    'suspicious',
    'sustainable',
    'swaggering',
    'swanky',
    'swaying',
    'sweaty',
    'sweeping',
    'sweet',
    'sweltering',
    'swift',
    'swimming',
    'swinish',
    'swishing',
    'swollen',
    'swooping',
    'syllabic',
    'syllogistic',
    'symbiotic',
    'symbolic',
    'symmetrical',
    'sympathetic',
    'symptomatic',
    'synergistic',
    'synonymous',
    'syntactic',
    'synthetic',
    'system',
    'systematic',
    't',
    'table',
    'taboo',
    'tacit',
    'tacky',
    'tactful',
    'tactical',
    'tactless',
    'tactual',
    'tainted',
    'take',
    'talented',
    'talk',
    'talkative',
    'tall',
    'taller',
    'tallest',
    'tame',
    'tamed',
    'tan',
    'tangential',
    'tangible',
    'tangled',
    'tangy',
    'tanned',
    'tantalizing',
    'tape',
    'tapered',
    'tardy',
    'target',
    'targeted',
    'tarnished',
    'tart',
    'task',
    'tasteful',
    'tasteless',
    'tasty',
    'tattered',
    'taunting',
    'taut',
    'tax',
    'taxing',
    'taylor',
    'tea',
    'teachable',
    'teacher',
    'team',
    'tearful',
    'tearing',
    'teasing',
    'technical',
    'technique',
    'technological',
    'technology',
    'tectonic',
    'tedious',
    'teenage',
    'teensy',
    'teeny',
    'telegraphic',
    'telekinetic',
    'telepathic',
    'telephone',
    'telephonic',
    'telescopic',
    'television',
    'telling',
    'temperamental',
    'temperate',
    'temperature',
    'tempered',
    'tempestuous',
    'temporary',
    'tempted',
    'tempting',
    'ten',
    'tenable',
    'tenacious',
    'tender',
    'tenderhearted',
    'tense',
    'tentative',
    'tenth',
    'tenuous',
    'tepid',
    'term',
    'terminal',
    'terrestrial',
    'terrible',
    'terrific',
    'terrified',
    'terrifying',
    'territorial',
    'terse',
    'test',
    'tested',
    'testy',
    'tetchy',
    'text',
    'textual',
    'textural',
    'than',
    'thankful',
    'thankless',
    'thatcher',
    'the',
    'theatre',
    'theatrical',
    'thematic',
    'theme',
    'theological',
    'theoretical',
    'theory',
    'therapeutic',
    'thermal',
    'thick',
    'thievish',
    'thin',
    'thing',
    'thinkable',
    'thinking',
    'third',
    'thirsty',
    'thorny',
    'thorough',
    'thought',
    'thoughtful',
    'thoughtless',
    'thrashed',
    'threat',
    'threatened',
    'threatening',
    'thriftless',
    'thrifty',
    'thrilled',
    'thrilling',
    'throbbing',
    'throw',
    'thumping',
    'thundering',
    'thunderous',
    'ticking',
    'tickling',
    'ticklish',
    'tidal',
    'tidy',
    'tight',
    'tightfisted',
    'time',
    'timeless',
    'timely',
    'timid',
    'timorous',
    'tiny',
    'tipsy',
    'tired',
    'tireless',
    'tiresome',
    'tiring',
    'title',
    'to',
    'tolerable',
    'tolerant',
    'tom',
    'tonal',
    'tone',
    'toneless',
    'tongued',
    'tony',
    'too',
    'toothsome',
    'toothy',
    'top',
    'topical',
    'topographical',
    'tormented',
    'torpid',
    'torrential',
    'torrid',
    'torturous',
    'total',
    'touch',
    'touched',
    'touching',
    'touchy',
    'tough',
    'tour',
    'towering',
    'town',
    'toxic',
    'track',
    'trade',
    'tradition',
    'traditional',
    'traffic',
    'tragedy',
    'tragic',
    'train',
    'trainable',
    'trained',
    'training',
    'traitorous',
    'tranquil',
    'transcendent',
    'transcendental',
    'transfer',
    'transformational',
    'transformative',
    'transformed',
    'transient',
    'transitional',
    'transitory',
    'translucent',
    'transparent',
    'transplanted',
    'transport',
    'trapped',
    'trashed',
    'trashy',
    'traumatic',
    'travel',
    'traveled',
    'treacherous',
    'treasonable',
    'treasonous',
    'treasured',
    'treatable',
    'treatment',
    'treaty',
    'tree',
    'tremendous',
    'tremulous',
    'trenchant',
    'trendy',
    'trial',
    'triangular',
    'tribal',
    'trick',
    'tricky',
    'trim',
    'trip',
    'tripping',
    'trite',
    'triumphant',
    'trivial',
    'tropical',
    'trouble',
    'troubled',
    'troublesome',
    'troubling',
    'truculent',
    'true',
    'trust',
    'trusted',
    'trustful',
    'trusting',
    'trustworthy',
    'trusty',
    'truth',
    'truthful',
    'trying',
    'tumultuous',
    'tuneful',
    'tuneless',
    'turbulent',
    'turn',
    'tv',
    'twinkling',
    'twinkly',
    'twisted',
    'twitchy',
    'type',
    'typical',
    'tyrannical',
    'tyrannous',
    'u',
    'ubiquitous',
    'ugly',
    'ultimate',
    'ultraconservative',
    'ultrasensitive',
    'ultrasonic',
    'ultraviolet',
    'un',
    'unabashed',
    'unabated',
    'unable',
    'unacceptable',
    'unaccompanied',
    'unaccountable',
    'unaccustomed',
    'unacknowledged',
    'unadorned',
    'unadulterated',
    'unadventurous',
    'unadvised',
    'unaffected',
    'unaffordable',
    'unafraid',
    'unaggressive',
    'unaided',
    'unalienable',
    'unalterable',
    'unaltered',
    'unambiguous',
    'unanimous',
    'unannounced',
    'unanswerable',
    'unanticipated',
    'unapologetic',
    'unappealing',
    'unappetizing',
    'unappreciative',
    'unapproachable',
    'unashamed',
    'unassailable',
    'unassertive',
    'unassisted',
    'unattached',
    'unattainable',
    'unattractive',
    'unauthorized',
    'unavailable',
    'unavailing',
    'unavoidable',
    'unbalanced',
    'unbearable',
    'unbeatable',
    'unbeaten',
    'unbecoming',
    'unbelievable',
    'unbelieving',
    'unbendable',
    'unbending',
    'unbiased',
    'unblemished',
    'unblinking',
    'unblushing',
    'unbounded',
    'unbreakable',
    'unbridled',
    'uncanny',
    'uncaring',
    'unceasing',
    'unceremonious',
    'uncertain',
    'unchangeable',
    'unchanging',
    'uncharacteristic',
    'uncharitable',
    'uncharted',
    'uncivil',
    'uncivilized',
    'unclassified',
    'uncle',
    'unclean',
    'uncluttered',
    'uncomely',
    'uncomfortable',
    'uncommitted',
    'uncommon',
    'uncommunicative',
    'uncomplaining',
    'uncomprehending',
    'uncompromising',
    'unconcerned',
    'unconditional',
    'unconfirmed',
    'unconquerable',
    'unconscionable',
    'unconscious',
    'unconstitutional',
    'unconstrained',
    'unconstructive',
    'uncontainable',
    'uncontrollable',
    'unconventional',
    'unconvinced',
    'unconvincing',
    'uncooked',
    'uncooperative',
    'uncoordinated',
    'uncouth',
    'uncovered',
    'uncreative',
    'uncritical',
    'undamaged',
    'undated',
    'undaunted',
    'undeclared',
    'undefeated',
    'undefined',
    'undemocratic',
    'undeniable',
    'undependable',
    'underdeveloped',
    'underfunded',
    'underhanded',
    'underprivileged',
    'understandable',
    'understanding',
    'understated',
    'understood',
    'undeserved',
    'undesirable',
    'undetected',
    'undeterred',
    'undeveloped',
    'undeviating',
    'undifferentiated',
    'undignified',
    'undiminished',
    'undiplomatic',
    'undisciplined',
    'undiscovered',
    'undisguised',
    'undisputed',
    'undistinguished',
    'undivided',
    'undoubted',
    'unearthly',
    'uneasy',
    'uneducated',
    'unemotional',
    'unemployed',
    'unemployment',
    'unencumbered',
    'unending',
    'unendurable',
    'unenforceable',
    'unenthusiastic',
    'unenviable',
    'unequal',
    'unequaled',
    'unequivocal',
    'unerring',
    'uneven',
    'uneventful',
    'unexceptional',
    'unexcited',
    'unexpected',
    'unexplainable',
    'unexplored',
    'unexpressive',
    'unfailing',
    'unfair',
    'unfaithful',
    'unfaltering',
    'unfamiliar',
    'unfashionable',
    'unfathomable',
    'unfavorable',
    'unfeeling',
    'unfettered',
    'unfilled',
    'unflagging',
    'unflappable',
    'unflattering',
    'unflinching',
    'unfocused',
    'unforeseeable',
    'unforgettable',
    'unforgivable',
    'unforgiving',
    'unfortunate',
    'unfriendly',
    'unfulfilled',
    'ungallant',
    'ungenerous',
    'ungentlemanly',
    'unglamorous',
    'ungraceful',
    'ungracious',
    'ungrateful',
    'unguarded',
    'unhandsome',
    'unhappy',
    'unharmed',
    'unhealthy',
    'unheated',
    'unheeded',
    'unhelpful',
    'unhesitating',
    'unhurried',
    'uniform',
    'unilateral',
    'unimaginable',
    'unimaginative',
    'unimpeachable',
    'unimpeded',
    'unimpressive',
    'unincorporated',
    'uninformed',
    'uninhabitable',
    'uninhibited',
    'uninitiated',
    'uninjured',
    'uninspired',
    'uninsurable',
    'unintelligent',
    'unintelligible',
    'unintended',
    'unintentional',
    'uninterested',
    'uninterrupted',
    'uninvited',
    'union',
    'unique',
    'unit',
    'unite',
    'united',
    'universal',
    'university',
    'unjust',
    'unjustifiable',
    'unkempt',
    'unkind',
    'unknowing',
    'unknown',
    'unlawful',
    'unlicensed',
    'unlikable',
    'unlikely',
    'unlivable',
    'unloved',
    'unlucky',
    'unmanageable',
    'unmanly',
    'unmanned',
    'unmarketable',
    'unmasked',
    'unmatched',
    'unmemorable',
    'unmentionable',
    'unmerciful',
    'unmistakable',
    'unmitigated',
    'unmodified',
    'unmotivated',
    'unnatural',
    'unnecessary',
    'unnerved',
    'unnerving',
    'unnoticeable',
    'unobserved',
    'unobtainable',
    'unobtrusive',
    'unofficial',
    'unopened',
    'unopposed',
    'unorthodox',
    'unostentatious',
    'unpalatable',
    'unpardonable',
    'unpersuasive',
    'unperturbed',
    'unplanned',
    'unpleasant',
    'unprecedented',
    'unpredictable',
    'unpretentious',
    'unprincipled',
    'unproductive',
    'unprofessional',
    'unprofitable',
    'unpromising',
    'unpronounceable',
    'unprovoked',
    'unqualified',
    'unquantifiable',
    'unquenchable',
    'unquestionable',
    'unquestioned',
    'unquestioning',
    'unraveled',
    'unreachable',
    'unreadable',
    'unrealistic',
    'unrealized',
    'unreasonable',
    'unreceptive',
    'unrecognizable',
    'unrecognized',
    'unredeemable',
    'unregulated',
    'unrelenting',
    'unreliable',
    'unremarkable',
    'unremitting',
    'unrepentant',
    'unrepresentative',
    'unrepresented',
    'unreserved',
    'unrespectable',
    'unresponsive',
    'unrestrained',
    'unripe',
    'unrivaled',
    'unromantic',
    'unruffled',
    'unruly',
    'unsafe',
    'unsalvageable',
    'unsatisfactory',
    'unsatisfied',
    'unscheduled',
    'unscholarly',
    'unscientific',
    'unscrupulous',
    'unseasonable',
    'unseemly',
    'unselfish',
    'unsettled',
    'unsettling',
    'unshakable',
    'unshapely',
    'unsightly',
    'unsigned',
    'unsinkable',
    'unskilled',
    'unsociable',
    'unsolicited',
    'unsolvable',
    'unsolved',
    'unsophisticated',
    'unsound',
    'unsparing',
    'unspeakable',
    'unspoiled',
    'unstable',
    'unstated',
    'unsteady',
    'unstoppable',
    'unstressed',
    'unstructured',
    'unsubstantial',
    'unsubstantiated',
    'unsuccessful',
    'unsuitable',
    'unsuited',
    'unsupervised',
    'unsupported',
    'unsure',
    'unsurpassable',
    'unsurpassed',
    'unsurprising',
    'unsuspected',
    'unsuspecting',
    'unsustainable',
    'unsympathetic',
    'unsystematic',
    'untainted',
    'untamable',
    'untamed',
    'untapped',
    'untenable',
    'untested',
    'unthinkable',
    'unthinking',
    'untidy',
    'untimely',
    'untitled',
    'untouchable',
    'untraditional',
    'untrained',
    'untried',
    'untroubled',
    'untrustworthy',
    'untruthful',
    'unused',
    'unusual',
    'unverified',
    'unwary',
    'unwashed',
    'unwatchable',
    'unwavering',
    'unwholesome',
    'unwieldy',
    'unwilling',
    'unwise',
    'unwitting',
    'unworkable',
    'unworldly',
    'unworthy',
    'unwritten',
    'unyielding',
    'up',
    'upbeat',
    'upmost',
    'upper',
    'uppity',
    'upright',
    'uproarious',
    'upset',
    'upsetting',
    'upstairs',
    'uptight',
    'upward',
    'urban',
    'urbane',
    'urgent',
    'us',
    'usable',
    'use',
    'used',
    'useful',
    'useless',
    'user',
    'usual',
    'utilitarian',
    'utopian',
    'utter',
    'uttermost',
    'v',
    'vacant',
    'vacillating',
    'vacuous',
    'vagabond',
    'vagrant',
    'vague',
    'vain',
    'valiant',
    'valid',
    'valley',
    'valorous',
    'valuable',
    'value',
    'van',
    'vanishing',
    'vapid',
    'vaporous',
    'variable',
    'varied',
    'variety',
    'various',
    'varying',
    'vast',
    'vegetable',
    'vegetarian',
    'vegetative',
    'vehement',
    'vehicle',
    'velvety',
    'venal',
    'venerable',
    'vengeful',
    'venomous',
    'venturesome',
    'venturous',
    'veracious',
    'verbal',
    'verbose',
    'verdant',
    'verifiable',
    'verified',
    'veritable',
    'vernacular',
    'versatile',
    'versed',
    'version',
    'vertical',
    'very',
    'vexed',
    'vexing',
    'viable',
    'vibrant',
    'vibrating',
    'vicarious',
    'vice',
    'vicious',
    'victim',
    'victorious',
    'victory',
    'video',
    'view',
    'vigilant',
    'vigorous',
    'vile',
    'village',
    'villain',
    'villainous',
    'vindictive',
    'vinegary',
    'violence',
    'violent',
    'violet',
    'viperous',
    'viral',
    'virtual',
    'virtue',
    'virtuous',
    'virulent',
    'visceral',
    'viscous',
    'visible',
    'vision',
    'visionary',
    'visit',
    'visual',
    'vital',
    'vitriolic',
    'vivacious',
    'vivid',
    'vocal',
    'vocational',
    'voice',
    'voiceless',
    'volatile',
    'volcanic',
    'volume',
    'voluminous',
    'voluntary',
    'voluptuous',
    'voracious',
    'vote',
    'vowel',
    'vulgar',
    'vulnerable',
    'w',
    'wacky',
    'wailing',
    'waiting',
    'wakeful',
    'walk',
    'wall',
    'wandering',
    'wanting',
    'wanton',
    'war',
    'warlike',
    'warm',
    'warmest',
    'warning',
    'warring',
    'wary',
    'waspish',
    'waste',
    'wasted',
    'wasteful',
    'watchful',
    'water',
    'waterlogged',
    'waterproof',
    'watertight',
    'watery',
    'wavering',
    'wax',
    'waxen',
    'way',
    'weak',
    'weakened',
    'wealth',
    'wealthy',
    'wearisome',
    'weary',
    'weather',
    'wee',
    'weedy',
    'week',
    'weekend',
    'weekly',
    'weight',
    'weightless',
    'weighty',
    'weird',
    'welcoming',
    'welfare',
    'well',
    'west',
    'western',
    'wet',
    'wheezing',
    'while',
    'whimpering',
    'whimsical',
    'whining',
    'whispering',
    'whistling',
    'white',
    'whole',
    'wholehearted',
    'wholesale',
    'wholesome',
    'whooping',
    'whopping',
    'wicked',
    'wide',
    'widespread',
    'wife',
    'wiggly',
    'wild',
    'will',
    'willed',
    'willful',
    'willing',
    'wily',
    'wind',
    'winded',
    'window',
    'windy',
    'wine',
    'winning',
    'winsome',
    'winter',
    'wintery',
    'wiry',
    'wise',
    'wishful',
    'wispy',
    'wistful',
    'withering',
    'witless',
    'witted',
    'witty',
    'wizardly',
    'wobbly',
    'woeful',
    'wolfish',
    'woman',
    'wonderful',
    'wondrous',
    'wonted',
    'wood',
    'wooden',
    'wooing',
    'wool',
    'woolen',
    'woozy',
    'word',
    'wordless',
    'wordy',
    'work',
    'workable',
    'worker',
    'working',
    'world',
    'worldly',
    'worn',
    'worried',
    'worrisome',
    'worrying',
    'worse',
    'worshipful',
    'worst',
    'worth',
    'worthless',
    'worthwhile',
    'worthy',
    'wounding',
    'wrathful',
    'wrenching',
    'wretched',
    'wriggling',
    'wriggly',
    'wrinkled',
    'wrinkly',
    'writer',
    'written',
    'wrong',
    'wrongful',
    'wry',
    'x',
    'xenial',
    'xenophobic',
    'y',
    'yawning',
    'year',
    'yearly',
    'yearning',
    'yellow',
    'yelping',
    'yes',
    'yielding',
    'young',
    'younger',
    'youngest',
    'youth',
    'youthful',
    'yummy',
    'z',
    'zany',
    'zealous',
    'zenith',
    'zestful',
    'zesty',
    'zippy',
    'zonked',
    'zoological',
    '{',
    '|',
    '}',
    '~'}


import re
import json
import itertools
from collections import Counter

class Tokenizer:
    def __init__(self, max_vocab=3000):
        # fixed specials
        self.specials = ['<PAD>', '<NS>', '<UP>', '<CAP>']
        self.max_vocab = max_vocab

        # to be built in train() or load()
        self.tokens = []
        self.bpe_merges = []
        self.token2id = {}
        self.id2token = {}
        self.vocab_size = 0
        self.bpe_slots = 0

    def train(self, texts):
        # 1) Top-400 words >3 chars
        wc = Counter()
        for t in texts:
            words = re.findall(r"\b\w+\b", t.lower())
            wc.update(w for w in words if len(w)>3 and not w.isdigit())
        top_words = [w for w,_ in wc.most_common(400)]

        # 2) Number tokens
        nums = [str(i) for i in range(100)]
        # 3) Single letters
        letters = [chr(c) for c in range(97,123)]
        # 4) All bigrams
        bigrams = [''.join(p) for p in itertools.product(letters, repeat=2)]

        # assemble base
        base = self.specials + nums + letters + bigrams + top_words
        self.tokens = base.copy()
        self.vocab_size = len(self.tokens)
        self.bpe_slots = self.max_vocab - self.vocab_size
        if self.bpe_slots < 0:
            raise ValueError(f"Base vocab ({self.vocab_size}) exceeds {self.max_vocab}")

        # prepare word‑freq for BPE
        word_freq = Counter()
        for w,c in wc.items():
            word_freq[tuple(w)] = c

        # 5) BPE training
        merges = []
        for _ in range(self.bpe_slots):
            # count only pairs whose merged form is length >=3
            pairs = Counter()
            for word, freq in word_freq.items():
                for i in range(len(word)-1):
                    a, b = word[i], word[i+1]
                    if len(a + b) < 3:
                        continue
                    pairs[(a, b)] += freq
            if not pairs:
                break

            best = max(pairs, key=pairs.get)
            merges.append(best)

            # apply that merge
            new_wf = Counter()
            for word, freq in word_freq.items():
                seq, i = [], 0
                while i < len(word):
                    if (i < len(word)-1 and 
                        (word[i], word[i+1]) == best):
                        seq.append(word[i] + word[i+1])
                        i += 2
                    else:
                        seq.append(word[i])
                        i += 1
                new_wf[tuple(seq)] += freq
            word_freq = new_wf

        self.bpe_merges = merges
        self.tokens += [''.join(a+b) for a,b in merges]
        self.token2id = {t:i for i,t in enumerate(self.tokens)}
        self.id2token = {i:t for t,i in self.token2id.items()}
        self.vocab_size = len(self.tokens)
        self.bpe_slots = self.max_vocab - self.vocab_size

    def save(self, prefix):
        # writes prefix+"_vocab.json" and prefix+"_merges.json"
        with open(prefix+"_vocab.json","w",encoding="utf-8") as f:
            json.dump(self.tokens, f, ensure_ascii=False, indent=2)
        with open(prefix+"_merges.json","w",encoding="utf-8") as f:
            json.dump(self.bpe_merges, f, ensure_ascii=False)

    @classmethod
    def load(cls, prefix, max_vocab=3000):
        tok = cls(max_vocab)
        with open(prefix+"_vocab.json","r",encoding="utf-8") as f:
            tok.tokens = json.load(f)
        with open(prefix+"_merges.json","r",encoding="utf-8") as f:
            tok.bpe_merges = [tuple(m) for m in json.load(f)]
        tok.token2id = {t:i for i,t in enumerate(tok.tokens)}
        tok.id2token = {i:t for t,i in tok.token2id.items()}
        tok.vocab_size = len(tok.tokens)
        tok.bpe_slots = max_vocab - tok.vocab_size
        return tok

    def _split_number(self, s):
        parts, r = [], s
        while r:
            parts.insert(0, r[-2:])
            r = r[:-2]
        return parts

    def _bpe_segment(self, word):
        seq = list(word)
        for a,b in self.bpe_merges:
            i, new = 0, []
            while i < len(seq):
                if i < len(seq)-1 and (seq[i], seq[i+1]) == (a,b):
                    new.append(a+b)
                    i += 2
                else:
                    new.append(seq[i])
                    i += 1
            seq = new
        return seq

    def _segment(self, word):
        """DP segmentation: minimize number of tokens."""
        L = len(word)
        dp = [float('inf')] * (L+1)
        back = [None] * (L+1)
        dp[L] = 0

        for i in range(L-1, -1, -1):
            # try every substring word[i:j]
            for j in range(i+1, L+1):
                sub = word[i:j]
                if sub in self.token2id and dp[j] + 1 < dp[i]:
                    dp[i] = dp[j] + 1
                    back[i] = (j, sub)
        if dp[0] == float('inf'):
            raise ValueError(f"Cannot tokenize: {word}")

        # reconstruct tokens
        tokens = []
        i = 0
        while i < L:
            j, sub = back[i]
            tokens.append(sub)
            i = j
        return tokens

    def tokenize(self, text):
        out = []
        for raw in text.strip().split():
            w = raw
            # case markers
            if w.isupper():
                out.append('<UP>'); w = w.lower()
            elif w[0].isupper():
                out.append('<CAP>'); w = w.lower()

            # numeric split
            if w.isdigit():
                parts = self._split_number(w)
            else:
                parts = self._segment(w)

            # inject <NS> between parts
            out.append(parts[0])
            for p in parts[1:]:
                out.extend(['<NS>', p])

        return out

    def convert_tokens_to_ids(self, toks):
        return [self.token2id[t] for t in toks]

    def pad(self, ids, max_len):
        pad_id = self.token2id['<PAD>']
        return ids + [pad_id]*(max_len-len(ids)) if len(ids)<max_len else ids[:max_len]

    def encode(self, text, max_length=None):
        toks = self.tokenize(text)
        ids  = self.convert_tokens_to_ids(toks)
        return self.pad(ids, max_length) if max_length else ids

    def decode(self, ids):
        toks = [self.id2token[i] for i in ids if self.id2token[i] != '<PAD>']
        words, i = [], 0
        while i < len(toks):
            w = toks[i]; i+=1
            while i+1<len(toks) and toks[i]=='<NS>':
                w += toks[i+1]; i+=2
            words.append(w)
        return ' '.join(words)



from setuptools import setup, find_packages

setup(
    name='mini_toker',
    version='0.2.0',
    description='A custom tokenizer with advanced token handling.',
    author='Yashraj Singh Rawat',
    packages=find_packages(),
    include_package_data=True,
    package_data={'mini_tokenizer': ['tokens.txt']},
    python_requires='>=3.6',
)
